/*
*  program name: Rubrica <http://digilander.iol.it/nfragale/download.html>
*  file: prefer.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf-client.h>
#include <gconf/gconf-schema.h>
#include <libxml/tree.h>
#include <time.h>

#include "main.h"
#include "error.h"
#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer.h"
#include "prefer-configure.h"
#include "rubrica.h"

gboolean user_dictionary_loaded;

GConfClient *rubrica_preferences_get_client(void)
{
  GtkWidget *prefbox;
  GConfClient *client;

  prefbox = rubrica_preferences_get_preferencesbox();
  client = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  return (GConfClient *) client;
}


GConfChangeSet *rubrica_preferences_get_change_set(GtkWidget *prefbox)
{
  return gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
}


void rubrica_preferences_update_sensitivity(GtkWidget *prefbox)
{
  GtkWidget* apply;
  GtkWidget* revert;
  GtkWidget* ok;

  GConfChangeSet* cs;
  GConfChangeSet* revert_cs;
  
  ok     = gtk_object_get_data(GTK_OBJECT(prefbox), "ok");
  apply  = gtk_object_get_data(GTK_OBJECT(prefbox), "apply");
  revert = gtk_object_get_data(GTK_OBJECT(prefbox), "revert");
  
  cs = rubrica_preferences_get_change_set(prefbox);
  revert_cs = gtk_object_get_data(GTK_OBJECT(prefbox), "revert_cs");

  if (gconf_change_set_size(cs) > 0)
    {
      gtk_widget_set_sensitive(ok, TRUE);
      gtk_widget_set_sensitive(apply, TRUE);
    }
  else
    {
      gtk_widget_set_sensitive(ok, TRUE);
      gtk_widget_set_sensitive(apply, FALSE);
    }
  
  if (revert_cs != NULL)
    gtk_widget_set_sensitive(revert, TRUE);
  else
    gtk_widget_set_sensitive(revert, FALSE);  
}


void rubrica_preferences_apply(GtkWidget *prefbox)
{

  GConfChangeSet *cs;
  GConfChangeSet *revert_cs;
  GConfClient *client;
  
  cs        = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  client    = gtk_object_get_data(GTK_OBJECT(prefbox), "client");
  revert_cs = gtk_object_get_data(GTK_OBJECT(prefbox), "revert_cs");
  
  /* Create the revert changeset on the first apply; this means
     the revert button should now be sensitive */
  if (revert_cs == NULL) {
    revert_cs=gconf_client_change_set_from_current(client, NULL,
						   RUBRICA_KEY_LAST_RUN,      
						   RUBRICA_KEY_SHOW,           
						   RUBRICA_KEY_HAVE_BOOK, 
						   RUBRICA_KEY_BOOK,
						   RUBRICA_KEY_HAVE_FOLDER,
						   RUBRICA_KEY_FOLDER, 
						   RUBRICA_KEY_BACKUP,
						   RUBRICA_KEY_BACKUP_TYPE_INC,
						   RUBRICA_KEY_BACKUP_TYPE_BAK,
						   RUBRICA_KEY_COMPRESS,
						   RUBRICA_KEY_RATE, 
						   RUBRICA_KEY_AUTOSAVE,
						   RUBRICA_KEY_WAIT_TIME,
						   RUBRICA_KEY_INCREASE,
						   RUBRICA_KEY_ALPHA_ORDER,
						   RUBRICA_KEY_DATE_ORDER,  
						   RUBRICA_KEY_SENSITIVE,
						   RUBRICA_KEY_COMPLETE,
						   RUBRICA_KEY_INCOMPLETE, 
						   RUBRICA_KEY_SEARCH,
						   RUBRICA_KEY_EXIT,    
						   RUBRICA_KEY_TIPS,     
						   RUBRICA_KEY_DEFAULT,  
						   RUBRICA_KEY_EXTERNAL,
						   RUBRICA_KEY_ITALIAN,  
						   RUBRICA_KEY_ENGLISH,
						   RUBRICA_KEY_USER_DICTIONARY,
						   RUBRICA_KEY_SHOW_COLUMN_CARD,
						   RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME,
						   RUBRICA_KEY_SHOW_COLUMN_LAST_NAME,
						   RUBRICA_KEY_SHOW_COLUMN_PROFESSION,
						   RUBRICA_KEY_SHOW_COLUMN_CITY,
						   RUBRICA_KEY_SHOW_COLUMN_COUNTRY,
						   RUBRICA_KEY_SHOW_COLUMN_WEB,
						   RUBRICA_KEY_SHOW_COLUMN_EMAIL,
						   RUBRICA_KEY_SHOW_COLUMN_TELEPHONE,
						   RUBRICA_KEY_SHOW_COLUMN_COMPANY,
						   RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT,
						   RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME,
						   RUBRICA_KEY_SHOW_DATA_NAME_PREFIX,
						   RUBRICA_KEY_SHOW_DATA_TITLE,
						   RUBRICA_KEY_SHOW_DATA_BIRTHDAY,
						   RUBRICA_KEY_SHOW_DATA_STREET,
						   RUBRICA_KEY_SHOW_DATA_STREET_NUM,
						   RUBRICA_KEY_SHOW_DATA_ZIP_CODE,
						   RUBRICA_KEY_SHOW_DATA_PROVINCE,
						   RUBRICA_KEY_SHOW_DATA_STATE,
						   RUBRICA_KEY_SHOW_DATA_COMPANY,
						   RUBRICA_KEY_SHOW_DATA_JOB_STREET,
						   RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM,
						   RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE,
						   RUBRICA_KEY_SHOW_DATA_JOB_CITY,
						   RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE,
						   RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY,
						   RUBRICA_KEY_SHOW_DATA_JOB_WEB,
						   RUBRICA_KEY_SHOW_DATA_JOB_EMAIL,
						   RUBRICA_KEY_SHOW_DATA_OPERATOR,
						   RUBRICA_KEY_SHOW_DATA_FAX,
						   RUBRICA_KEY_SHOW_DATA_GREEN,
						   RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE,
						   RUBRICA_KEY_SHOW_DATA_JOB_NOTE,
						   RUBRICA_KEY_SHOW_DATA_ASSIGMENT,
						   RUBRICA_KEY_SHOW_DATA_ORG,
						   RUBRICA_KEY_SHOW_DATA_DEP,
						   RUBRICA_KEY_SHOW_DATA_SUB_DEP,
						   RUBRICA_KEY_SHOW_DATA_SECRETARY,
						   RUBRICA_KEY_SHOW_DATA_SECR_PHONE,
						   RUBRICA_KEY_SHOW_DATA_MARRIED,
						   RUBRICA_KEY_SHOW_DATA_SPOUSE,
						   RUBRICA_KEY_SHOW_DATA_CHILDREN,
						   RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH,
						   RUBRICA_KEY_SHOW_DATA_CHILD_NOTE,
						   RUBRICA_KEY_SHOW_DATA_NOTE,
						   RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME,
						   RUBRICA_KEY_SHOW_DATA_JOB_SOME,
						   RUBRICA_KEY_SHOW_DATA_NOTES_SOME,
						   RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL,
						   RUBRICA_KEY_SHOW_DATA_JOB_ALL,
						   RUBRICA_KEY_SHOW_DATA_NOTES_ALL,
						   NULL);
    
    gtk_object_set_data(GTK_OBJECT(prefbox), "revert_cs", revert_cs);
  }      
  
  gconf_client_commit_change_set(client, cs, TRUE, NULL);
  
  rubrica_preferences_update_sensitivity(prefbox);
} 

void rubrica_preferences_set_data(GtkWidget *prefbox, gchar *key)
{
  GtkWidget *button;
  GConfChangeSet *cs;  

  button  = gtk_object_get_data(GTK_OBJECT(prefbox), key); 
  cs      = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");  

  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
  gconf_change_set_set_bool(cs, key, TRUE);
  
  rubrica_preferences_update_sensitivity(prefbox);
}


/****************** 
 *                *
 *  GET ROUTINES  *
 *                *
 ******************/

/*  return true is this is the first time that 
    rubrica is running after gconf "era"    
 */
gboolean rubrica_preferences_get_first_run(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_FIRST_RUN, NULL);

  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_FIRST_RUN, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_FIRST_RUN, NULL);   
  
  return TRUE;
}

/*  return the last time rubrica was run
*/
gint rubrica_preferences_get_last_run(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_LAST_RUN, NULL);

  if (value == NULL || value->type != GCONF_VALUE_INT)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_LAST_RUN, NULL); 

  if (value)
    return gconf_client_get_int(client, RUBRICA_KEY_LAST_RUN, NULL);   
  
  return time(NULL);
}

/*  return last opened addressbook
*/
gchar *rubrica_preferences_get_last_book(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_LAST_BOOK, NULL);

  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_LAST_BOOK, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_LAST_BOOK, NULL);    
  
  return NULL;
}

/*  return user home directory
*/
gchar *rubrica_preferences_get_home(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HOME, NULL);

  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HOME, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_HOME, NULL);    
  /* else */
  return NULL; 
}


gboolean rubrica_preferences_get_show_path(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW, NULL);

  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW, NULL);   

  return TRUE;
}

/*
  return true if user wants that rubrica load an addressbook at start
  false otherwise
*/
gboolean rubrica_preferences_get_have_default_addressbook(void)
{
  GConfClient *client;
  GConfValue  *value;

  client  = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HAVE_BOOK, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HAVE_BOOK, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_HAVE_BOOK, NULL);  

  return FALSE;
}

/* 
   is user wants start with an addressbook, this funcion returns  
   addressbook's path and file
*/
gchar *rubrica_preferences_get_book(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_BOOK, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_BOOK, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_BOOK, NULL);   
  else
    rubrica_error_display_preferences_messages("rubrica_preferences_get_book");

  return NULL;
}

/*
  return true if users wants to save all 
  addressbook in a default folder
*/
gboolean rubrica_preferences_get_have_default_folder(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HAVE_FOLDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HAVE_FOLDER, NULL); 

  if (value)
    return gconf_client_get_bool(client, RUBRICA_KEY_HAVE_FOLDER, NULL);    

  return FALSE;
}

/* 
   if user wants to save addressbook in a 
   default folder, this function return the folder
*/
gchar* rubrica_preferences_get_default_folder(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_FOLDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_FOLDER, NULL); 

  if (value)
    return gconf_client_get_string(client, RUBRICA_KEY_FOLDER, NULL);  

  return NULL;
}

/*
  return true is user want to do backup
*/
gboolean rubrica_preferences_get_do_backup(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_BACKUP, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_BACKUP, NULL); 
  
  if (value) 
    return gconf_client_get_bool(client, RUBRICA_KEY_BACKUP, NULL);  

  return FALSE;
}

/*
  return backup type value
*/
gboolean rubrica_preferences_get_backup_type(gchar *key)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, key, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, key, NULL);
  
  if (value) 
    return gconf_client_get_bool(client, key, NULL);  
  
  return FALSE;
}

gboolean rubrica_preferences_get_backup_is_increasing(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_BACKUP_TYPE_INC, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, 
						 RUBRICA_KEY_BACKUP_TYPE_INC,
						 NULL);
  
  if (value) 
    return gconf_client_get_bool(client, RUBRICA_KEY_BACKUP_TYPE_INC, NULL);  
  else
    {
      value  = gconf_client_get(client, RUBRICA_KEY_BACKUP_TYPE_BAK, NULL);
      
      if (value == NULL || value->type != GCONF_VALUE_BOOL)
	value = gconf_client_get_default_from_schema(client, 
						     RUBRICA_KEY_BACKUP_TYPE_BAK, 
						     NULL);
      
      if (value) 
	return !gconf_client_get_bool(client, RUBRICA_KEY_BACKUP_TYPE_BAK, NULL);       
    }  
  
  return TRUE;  
}


/*
  return true if user want to compress his addressbooks
*/
gboolean rubrica_preferences_get_compress(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_COMPRESS, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_COMPRESS, NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_COMPRESS, NULL);  

  return FALSE;
}

/* 
   if user wants compressed addressbooks. this funcion return 
   the compression rate
*/
gint rubrica_preferences_get_compress_rate(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_RATE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_INT)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_RATE, NULL); 

  if (value)  
    return gconf_client_get_int(client, RUBRICA_KEY_RATE, NULL);  
  
  return 0;
}

/*
  return true if user wants autosave enable
*/
gboolean rubrica_preferences_get_autosave(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_AUTOSAVE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_AUTOSAVE, NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_AUTOSAVE, NULL);  

  return FALSE;
}

/* 
   if user wants the autosave, this funcion return 
   the minutes between two saves
*/
gint rubrica_preferences_get_time_rate(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_WAIT_TIME, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_INT)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_WAIT_TIME, NULL); 

  if (value)  
    return gconf_client_get_int(client, RUBRICA_KEY_WAIT_TIME, NULL);  
  
  return 0;
}

/* 
   return true if cards's order is increasing
   return false if cards's order is decreasing
*/
gboolean rubrica_preferences_get_increasing_order(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_INCREASE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_INCREASE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_INCREASE, NULL);

  return TRUE;
}

/*
  return true if cards order is alphabetic
*/
gboolean rubrica_preferences_get_alphabetic_order(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_ALPHA_ORDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_ALPHA_ORDER, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_ALPHA_ORDER, NULL);

  return TRUE;
}

/*
  return true if cards order is by date
*/
gboolean rubrica_preferences_get_date_order(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_DATE_ORDER, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_DATE_ORDER, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_DATE_ORDER, NULL);

  return FALSE;
}

/*
  return true if search is case sensitive
*/
gboolean rubrica_preferences_get_case_sensitive_search(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SENSITIVE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SENSITIVE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_SENSITIVE, NULL);

  return TRUE;
}

/*
  return true if search is on complete string
*/
gboolean rubrica_preferences_get_complete_search(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_COMPLETE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_COMPLETE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_COMPLETE, NULL);

  return TRUE;
}

/*
  return true if search is on incomplete string
*/
gboolean rubrica_preferences_get_incomplete_search(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_INCOMPLETE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_INCOMPLETE, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_INCOMPLETE, NULL);

  return FALSE;
}


/*
  return true if user want to exit without confirm
*/
gboolean rubrica_preferences_get_exit(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_EXIT, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_EXIT, NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_EXIT, NULL);

  return TRUE;
}


/*
  return true is user want tips at start 
*/
gboolean rubrica_preferences_get_tips(void)
{
  GConfClient* client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_TIPS, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_TIPS, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_TIPS, NULL);

  return FALSE;
}

/*
  return true if user want to use one of  
  the default dictionary 
*/
gboolean rubrica_preferences_get_use_default_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_DEFAULT, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_DEFAULT, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_DEFAULT, NULL);

  return TRUE;
}

/*
  return true if user want to use an external 
  dictionary (personal dictionary)
*/
gboolean rubrica_preferences_get_use_user_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_EXTERNAL, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_EXTERNAL, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_EXTERNAL, NULL);

  return FALSE;
}

/*
  return true if user want to use italian dictionary 
*/
gboolean rubrica_preferences_get_use_italian_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_ITALIAN, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_ITALIAN, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_ITALIAN, NULL);

  return TRUE;
}


/*
  return true if user want to use english dictionary 
*/
gboolean rubrica_preferences_get_use_english_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_ENGLISH, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_ENGLISH, NULL); 

  if (value)   
    return gconf_client_get_bool(client, RUBRICA_KEY_ENGLISH, NULL);

  return FALSE;
}


/*
  return true if user has his dictionary
*/
gboolean rubrica_preferences_get_user_has_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_HAS_DICTIONARY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_HAS_DICTIONARY, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_HAS_DICTIONARY, NULL);  

  return FALSE;
}

gchar *rubrica_preferences_get_dictionary_home(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_DICTIONARY_HOME, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_DICTIONARY_HOME, 
						 NULL); 

  if (value)   
    return gconf_client_get_string(client, RUBRICA_KEY_DICTIONARY_HOME, NULL);    

  return NULL;
}


/*
  if user has dictionary, return dictionary filename
*/
gchar* rubrica_preferences_get_user_dictionary(void)
{
  GConfClient *client;
  GConfValue  *value;
  
  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_USER_DICTIONARY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_USER_DICTIONARY, NULL); 
  
  if (value)   
    return gconf_client_get_string(client, RUBRICA_KEY_USER_DICTIONARY, NULL);    

  return NULL;
}

/*  get the value of a generic key
*/
gchar *rubrica_preferences_get_string_key(gchar *key)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, key, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, key, NULL); 

  if (value)   
    return gconf_client_get_string(client, key, NULL);  

  return NULL;
}


/*
  return user dictionary language
  (language is equal to dictionary filename)
  Klingon language has Klingon.dict dictionary
*/
gchar* rubrica_preferences_get_language(void)
{
  GConfClient *client;
  GConfValue  *value;
  gchar *buffer = NULL, *str = NULL;
  
  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_USER_DICTIONARY, NULL);

  if (value == NULL || value->type != GCONF_VALUE_STRING)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_USER_DICTIONARY, NULL); 

  if (value)
    {
      buffer = gconf_client_get_string(client, RUBRICA_KEY_USER_DICTIONARY, NULL);
  
      if (buffer)
	{
	  str = g_basename(buffer);
	  g_strreverse(str);
	  strtok(str, ".");
	  g_strreverse(str);
	}
      else
	str = NULL;
    }
  
  return (gchar*) str;
}


/******************
 *                *
 *  SET ROUTINES  *
 *                *
 ******************/
void rubrica_preferences_set_first_run(gboolean bool)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_bool(client, RUBRICA_KEY_FIRST_RUN, bool, NULL);  
}
  
void rubrica_preferences_set_last_run(time_t last_run)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_int(client, RUBRICA_KEY_LAST_RUN, last_run, NULL);  
}

void rubrica_preferences_set_last_book(gchar *filename)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_LAST_BOOK, filename, NULL);   
}

void rubrica_preferences_set_home(gchar *home)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_HOME, home, NULL);   
}

void rubrica_preferences_set_have_default_book(gboolean bool)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_bool(client, RUBRICA_KEY_HAVE_BOOK, bool, NULL);  
}

void rubrica_preferences_set_have_default_folder(gboolean bool)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_bool(client, RUBRICA_KEY_HAVE_FOLDER, bool, NULL);  
}

void rubrica_preferences_set_book(gchar *str)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_BOOK, str, NULL);  
}

void rubrica_preferences_set_folder(gchar *str)
{
  GConfClient *client;

  client  = rubrica_get_client();
  
  gconf_client_set_string(client, RUBRICA_KEY_FOLDER, str, NULL);  
}


void rubrica_preferences_set_compress_rate(gint rate)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_int(client, RUBRICA_KEY_RATE, rate, NULL);  
}

void rubrica_preferences_set_time_rate(gint rate)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_int(client, RUBRICA_KEY_WAIT_TIME, rate, NULL);  
}

void rubrica_preferences_set_increasing_order(gboolean state)
{
  GConfClient* client;
  
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_INCREASE, state, NULL);
}


void rubrica_preferences_set_alphabetic_order(gboolean state)
{
  GConfClient* client;
  
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_ALPHA_ORDER, state, NULL);
}


void rubrica_preferences_set_date_order(gboolean state)
{
  GConfClient* client;
  
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_DATE_ORDER, state, NULL);
}


void rubrica_preferences_set_case_sensitive_search(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_SENSITIVE, state, NULL);  
}

void rubrica_preferences_set_complete_search(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_COMPLETE, state, NULL);  
}

void rubrica_preferences_set_incomplete_search(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_INCOMPLETE, state, NULL);
}

void rubrica_preferences_set_tips(gboolean state)
{
  GConfClient *client;
 
  client  = rubrica_get_client();

  gconf_client_set_bool(client, RUBRICA_KEY_TIPS, state, NULL);
}

void rubrica_preferences_set_user_dictionary(gchar *dict)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, RUBRICA_KEY_USER_DICTIONARY, dict, NULL);   
}

void rubrica_preferences_set_dictionary_home(gchar *homedict)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, RUBRICA_KEY_DICTIONARY_HOME, homedict, NULL);   
}


void rubrica_preferences_set_string_key(gchar *key, gchar *val)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, key, val, NULL);   
}

void rubrica_preferences_set_null_key(gchar *key)
{
  GConfClient *client;
  
  client  = rubrica_get_client();
  gconf_client_set_string(client, key, NULL, NULL);   
}

/* ********************** */
/* ********************** */

void rubrica_preferences_set_user_dictionary_loaded(gboolean state)
{
  user_dictionary_loaded = state;
}

gboolean rubrica_preferences_get_user_dictionary_loaded()
{
  return user_dictionary_loaded;
}


/*  ************************************************************ */
/* 
 *                   Determina quale colonne mostrare
 *                   Columns that rubrica must show
 */
gboolean rubrica_preferences_show_card(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_CARD, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_CARD, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_CARD, NULL);  

  return TRUE;
}

gboolean rubrica_preferences_show_first_name(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME, NULL);  

  return TRUE;
}


gboolean rubrica_preferences_show_last_name(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_LAST_NAME, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_LAST_NAME, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_LAST_NAME, NULL);  

  return TRUE;
}

gboolean rubrica_preferences_show_profession(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_PROFESSION, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_PROFESSION, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_PROFESSION, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_city(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_CITY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_CITY, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_CITY, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_country(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_COUNTRY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_COUNTRY, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_COUNTRY, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_web(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_WEB, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_WEB, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_WEB, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_email(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_EMAIL, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_EMAIL, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_EMAIL, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_telephone(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_TELEPHONE, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_TELEPHONE, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_TELEPHONE, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_company(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_COMPANY, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_COMPANY, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_COMPANY, NULL);  

  return FALSE;
}

gboolean rubrica_preferences_show_assigment(void)
{
  GConfClient *client;
  GConfValue  *value;

  client = rubrica_get_client();
  value  = gconf_client_get(client, RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT, NULL);
  
  if (value == NULL || value->type != GCONF_VALUE_BOOL)
    value = gconf_client_get_default_from_schema(client, RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT, 
						 NULL); 

  if (value)  
    return gconf_client_get_bool(client, RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT, NULL);  

  return FALSE;
}
