/*
*  program name: Rubrica <http://digilander.iol.it/nfragale/download.html>
*  file: prefer_cb.c
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gnome.h>
#include <gconf/gconf-client.h>
#include <libxml/tree.h>

#include "autosave.h"
#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer.h"
#include "prefer-revert.h"
#include "dictionary.h"
#include "addressbook.h"
#include "dialoghi.h"
#include "rubrica.h"



/*  preferences main window's callback functions:
    
    - ok     clicked
    - apply  clicked
    - revert clicked
    - close  clicked
*/
void
rubrica_preferences_ok_clicked (GtkButton *button, gpointer  user_data)
{
  GtkWidget* dialog = user_data;
  
  rubrica_preferences_apply(dialog);
  gtk_widget_hide(dialog); 
}


void
rubrica_preferences_apply_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox = user_data;

  rubrica_preferences_apply(prefbox);
}


void
rubrica_preferences_revert_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox = user_data;

  rubrica_preferences_revert(prefbox);
}


void 
rubrica_preferences_close_dialog  (GtkButton  *button, gpointer user_data)
{
  GtkWidget *w = user_data;

  gtk_widget_hide(w);
}



/*    widget callbacks
*/
void on_check_button_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(key != NULL);
  
  /*    get ptr to the preferences window dialog and to the GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  /* get the new button state */
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  /* per queste chiavi sono necessarie altre operazioni 
     those keys needs other steps
  */
  if ((strcmp(key, RUBRICA_KEY_HAVE_BOOK) == 0))
    {
      GtkWidget *gentry;
      GtkWidget *entry;
      gchar *key2;
      
      /* get addressbook ptrs */
      gentry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_BOOK);
      entry  = gtk_object_get_data(GTK_OBJECT(prefbox), "entry_addbook");
      key2   = g_strdup(RUBRICA_KEY_BOOK);
      
      gtk_widget_set_sensitive(gentry, state);

      if(!state)
	{      
	  gtk_entry_set_text(GTK_ENTRY(entry), "");
	  gconf_change_set_unset(cs, key2);      
	}
      
      g_free(key2); 
    }
  
  if ((strcmp(key, RUBRICA_KEY_HAVE_FOLDER) == 0))
    {
      GtkWidget *gentry;
      GtkWidget *entry;      
      gchar *key2;

      /* get folder ptrs */
      gentry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_FOLDER);
      entry  = gtk_object_get_data(GTK_OBJECT(prefbox), "entry_folder");      
      key2   = g_strdup(RUBRICA_KEY_FOLDER);
      
      gtk_widget_set_sensitive(gentry, state);

	if(!state)
	{      
	  gtk_entry_set_text(GTK_ENTRY(entry), "");
	  gconf_change_set_unset(cs, key2);      
	}
      
      g_free(key2); 
    }
  
  if (strcmp(key, RUBRICA_KEY_BACKUP) == 0)
    {
      GtkWidget *radio1;
      GtkWidget *radio2;
      
      radio1 = gtk_object_get_data(GTK_OBJECT(prefbox), "inc_bak");
      radio2 = gtk_object_get_data(GTK_OBJECT(prefbox), "bak_bak");
      
      if (state)
	{
	  gtk_widget_set_sensitive (radio1, TRUE);
	  gtk_widget_set_sensitive (radio2, TRUE);
	}
      else
	{
	  gtk_widget_set_sensitive (radio1, FALSE);
	  gtk_widget_set_sensitive (radio2, FALSE);
	}
    }
  
  if (strcmp(key, RUBRICA_KEY_COMPRESS) == 0)
    {
      GtkWidget *box;
      GtkWidget *spin;
      
      spin = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_RATE);
      box  = gtk_object_get_data(GTK_OBJECT(togglebutton), "spin_box");
      gtk_widget_set_sensitive(box, state);
      gtk_widget_set_sensitive(spin, state);
    }
  
  if (strcmp(key, RUBRICA_KEY_AUTOSAVE) == 0)
    {
      GtkWidget *box; 
      GtkWidget *spin;
      gint time;
      
      box  = gtk_object_get_data(GTK_OBJECT(togglebutton), "spin_box");
      spin = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_WAIT_TIME);
      gtk_widget_set_sensitive(box, state);
      gtk_widget_set_sensitive(spin, state);

      if (state)
	{
	  time = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin));
	  
	  rubrica_autosave_enable(time);
	}
      else                           
	rubrica_autosave_disable();     
    }
  
  /* store the new value */
  gconf_change_set_set_bool(cs, key, state);
  
  /* update preferences buttons sensitivity */
  rubrica_preferences_update_sensitivity(prefbox);
}

void on_radio_button_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;

  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);

  /*    get ptr to preferences window dialog anto to GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  /*     backup radio button
  */
  if ((strcmp(key, RUBRICA_KEY_BACKUP_TYPE_INC) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_BACKUP_TYPE_INC, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_BACKUP_TYPE_BAK, !state);
    }

  if ((strcmp(key, RUBRICA_KEY_BACKUP_TYPE_BAK) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_BACKUP_TYPE_INC, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_BACKUP_TYPE_BAK, state);
    }  

  /*    alphabetic/date radio button
  */
  if ((strcmp(key, RUBRICA_KEY_ALPHA_ORDER) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ALPHA_ORDER, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DATE_ORDER, !state);
    }

  if ((strcmp(key, RUBRICA_KEY_DATE_ORDER) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ALPHA_ORDER, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DATE_ORDER, state);      
    }

  /*    search on complete/incomplete string radio button
  */
  if ((strcmp(key, RUBRICA_KEY_COMPLETE) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_COMPLETE, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_INCOMPLETE, !state);
    }

  if ((strcmp(key, RUBRICA_KEY_INCOMPLETE) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_COMPLETE, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_INCOMPLETE, state);      
    }

  if ((strcmp(key, RUBRICA_KEY_ITALIAN) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ITALIAN, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ENGLISH, !state);
    }

  if ((strcmp(key, RUBRICA_KEY_ENGLISH) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ITALIAN, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ENGLISH, state);      
    }
  
    if ((strcmp(key, RUBRICA_KEY_DEFAULT)  == 0) || 
	(strcmp(key, RUBRICA_KEY_EXTERNAL) == 0))
      {
	GtkWidget *radio_italian;
	GtkWidget *radio_english;
	GtkWidget *entry;
	GtkWidget *label_default;
	GtkWidget *label_language;
	GtkWidget *notebook;
	GtkWidget *label_io;
	GtkWidget *label_dict;
	GtkWidget *load;
	GtkWidget *save;

	load  = gtk_object_get_data(GTK_OBJECT(prefbox), "load");
	save  = gtk_object_get_data(GTK_OBJECT(prefbox), "save"); 
	entry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_USER_DICTIONARY);
	notebook   = gtk_object_get_data(GTK_OBJECT(prefbox), "notebook_dict");
	label_io   = gtk_object_get_data(GTK_OBJECT(prefbox), "label_io");
	label_dict = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
	label_language = gtk_object_get_data(GTK_OBJECT(prefbox), "label_language");
	radio_italian  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ITALIAN);
	radio_english  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ENGLISH);
	label_default  = gtk_object_get_data(GTK_OBJECT(prefbox), "label_default_dict");
	
	if ((strcmp(key, RUBRICA_KEY_DEFAULT) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_DEFAULT, state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_EXTERNAL, !state);  
	    
	    gtk_widget_set_sensitive(radio_italian, state);
	    gtk_widget_set_sensitive(radio_english, state);
	    gtk_widget_set_sensitive(label_default, state);
	    
	    gtk_widget_set_sensitive(entry, !state);
	    gtk_widget_set_sensitive(label_language, !state);
	    gtk_widget_set_sensitive(notebook, !state);
	    gtk_widget_set_sensitive(label_io, !state);
	    gtk_widget_set_sensitive(label_dict, !state);
	    gtk_widget_set_sensitive(load, !state); 
	    gtk_widget_set_sensitive(save, !state); 
	  }
	
	if ((strcmp(key, RUBRICA_KEY_EXTERNAL) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_DEFAULT, !state);  
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_EXTERNAL, state);      
	    
	    gtk_widget_set_sensitive(radio_italian, !state);
	    gtk_widget_set_sensitive(radio_english, !state);
	    gtk_widget_set_sensitive(label_default, !state);
	    
	    gtk_widget_set_sensitive(entry, state);
	    gtk_widget_set_sensitive(label_language, state);
	    gtk_widget_set_sensitive(notebook, state);
	    gtk_widget_set_sensitive(label_io, state);
	    gtk_widget_set_sensitive(label_dict, state);
	    gtk_widget_set_sensitive(load, state); 
	    gtk_widget_set_sensitive(save, state); 	    
	  }	
      }

	/* view_pers_data_table --> data_table
	   view_job_data_table  --> job_table
	   view_note_data_table --> note_table	   
	 */
    if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME) == 0) ||
	(strcmp(key, RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL) == 0))
      {
	GtkWidget *table;

	table = gtk_object_get_data(GTK_OBJECT(prefbox), "data_table");

	if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME, state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL, !state);  
	    
	    gtk_widget_set_sensitive(table, TRUE);
	    rubrica_addressbook_show_personal_data_set(FALSE);
	  }
	
	if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME, !state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL, state);  
	    
	    gtk_widget_set_sensitive(table, FALSE);
	    rubrica_addressbook_show_personal_data_set(TRUE);
	  }		
      }

    if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_SOME) == 0) ||
	(strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_ALL) == 0))
      {
	GtkWidget *table;

	table = gtk_object_get_data(GTK_OBJECT(prefbox), "job_table");

	if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_SOME) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_JOB_SOME, state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_JOB_ALL, !state);  
	    
	    gtk_widget_set_sensitive(table, TRUE);
	    rubrica_addressbook_show_job_data_set(FALSE);
	  }
	
	if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_ALL) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_JOB_SOME, !state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_JOB_ALL, state);  
	    
	    gtk_widget_set_sensitive(table, FALSE);
	    rubrica_addressbook_show_job_data_set(TRUE);
	  }		
      }

    if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTES_SOME) == 0) ||
	(strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTES_ALL) == 0))
      {
	GtkWidget *table;

	table = gtk_object_get_data(GTK_OBJECT(prefbox), "note_table");

	if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTES_SOME) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_NOTES_SOME, state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_NOTES_ALL, !state);  
	    
	    gtk_widget_set_sensitive(table, TRUE);
	    rubrica_addressbook_show_note_data_set(FALSE);
	  }
	
	if ((strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTES_ALL) == 0))
	  {
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_NOTES_SOME, !state);
	    gconf_change_set_set_bool(cs, RUBRICA_KEY_SHOW_DATA_NOTES_ALL, state);  
	    
	    gtk_widget_set_sensitive(table, FALSE);
	    rubrica_addressbook_show_note_data_set(TRUE);
	  }		
      }


    rubrica_preferences_update_sensitivity(prefbox);  
}



void on_spin_activate (GtkWidget *spin, gpointer user_data)
{ 
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gint val;
  gchar *key = user_data;

  g_return_if_fail(spin != NULL);
  g_return_if_fail(user_data != NULL);

  prefbox = rubrica_preferences_get_preferencesbox();

  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  val = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin));
  gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 0);

  /* store new compression rate in the key
     and set xml compression mode 
  */
  gconf_change_set_set_int(cs, key, val);

  if (strcmp(key, RUBRICA_KEY_RATE) == 0)
    xmlSetCompressMode(val);
  
/*
  if (strcmp(key, RUBRICA_KEY_WAIT_TIME) == 0)
    {
   1000 = 1 secondo, 60000 = 60 secondi = 1 minuto
	 se val = 10, il timeout si attiva ogni 10 minuti
  
      if (val == 0)
	{
	  if (have_timeout)
	    gtk_timeout_remove(timeout_tag);
	  
	  have_timeout = FALSE; 
	}
      else
	{
	  timeout_tag = gtk_timeout_add(val * 60000, (GtkFunction) rubrica_autosave, 
					NULL);
	  g_print("\ntimeout_tag: %d", timeout_tag);

	  have_timeout = TRUE;
	}
    }
*/

  rubrica_preferences_update_sensitivity(prefbox);
}


void on_entry_changed (GtkEditable *editable, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gchar *text;
  gchar *key = user_data;
  
  g_return_if_fail(editable != NULL);
  g_return_if_fail(user_data != NULL);  

  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  
  if ( (strcmp(key, RUBRICA_KEY_BOOK)   == 0) ||
       (strcmp(key, RUBRICA_KEY_FOLDER) == 0))
    {			    
      if (*text != '\0')
	gconf_change_set_set_string(cs, key, text);
      else
	gconf_change_set_unset(cs, key);
     
      g_free(text);
    }
  
  if (strcmp(key,RUBRICA_KEY_USER_DICTIONARY) == 0)
    {
      GtkWidget *label;
      
      label = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
      gtk_label_set_pattern(GTK_LABEL(label), NULL);
      
      /*    if text was entered show it into label, and set into changeset
       */
      if (strlen(text) > 0)
	{
	  gtk_label_set_text(GTK_LABEL(label), text);
	  rubrica_preferences_set_user_dictionary(text);
	  
	  gconf_change_set_set_string(cs, key, text);
	}
      else
	{
	  gtk_label_set_text(GTK_LABEL(label), "");
	  
	  gconf_change_set_unset(cs, key);      
	}      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}


/*  choose where search is performed
*/
void on_entry_search_changed(GtkEditable *editable, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gchar *str;
  gint  search_in = 0;  /* default search is in card */
  
  /*    get ptr to preferences window dialog anto to GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  str = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);

  if (strcmp(str, RUBRICA_SEARCH_CARD) == 0)
    search_in = 0;
  if (strcmp(str, RUBRICA_SEARCH_FIRST_NAME) == 0)
    search_in = 1;
  if (strcmp(str, RUBRICA_SEARCH_LAST_NAME) == 0)
    search_in = 2;
  if (strcmp(str, RUBRICA_SEARCH_PROFESSION) == 0)
    search_in = 3;
  if (strcmp(str, RUBRICA_SEARCH_CITY) == 0)
    search_in = 4;
  if (strcmp(str, RUBRICA_SEARCH_COUNTRY) == 0)
    search_in = 5;
  if (strcmp(str, RUBRICA_SEARCH_WEB_ADDRESS) == 0)
    search_in = 6;
  if (strcmp(str, RUBRICA_SEARCH_EMAIL_ADDRESS) == 0)
    search_in = 7;
  if (strcmp(str, RUBRICA_SEARCH_TELEPHONE) == 0)
    search_in = 8;

  gconf_change_set_set_int(cs, RUBRICA_KEY_SEARCH, search_in);  

  rubrica_preferences_update_sensitivity(prefbox);
}


/*  Callback richiamata ad ogni cambiamento
    delle entry relative al dizionario 
    contenuto nel notebook

    notebook entries's callbacks
*/
void 
on_dictionary_entry_changed(GtkEditable *editable, gpointer user_data)
{
  GtkWidget *prefbox;
  GConfClient *client;
  gchar *text;
  gchar *key = user_data;

  /* get ptr to dialog box */
  prefbox = rubrica_preferences_get_preferencesbox();

  /*    get ptr to GConf client  */
  client = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  /*    get the text typed into entry 
  */
  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  
  gconf_client_set_string(client, key, text, NULL);
}

/*  Notebook buttons's callbacks
*/
void
on_load_dictionary_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox;
  GConfClient *client;
  gboolean err;
 
  prefbox    = rubrica_preferences_get_preferencesbox();
  client     = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  err = rubrica_dictionary_load_user_dictionary(client);
  
  if (!err)
    rubrica_dictionary_display_dictionary(prefbox, client);
}

void
on_save_dictionary_clicked (GtkButton  *button, gpointer user_data)
{
  GtkWidget *prefbox;
  GConfClient *client;
  gchar *dictionary;
 
  prefbox = rubrica_preferences_get_preferencesbox();
  client = gtk_object_get_data(GTK_OBJECT(prefbox), "client");

  if (rubrica_preferences_get_use_user_dictionary())
    {
      dictionary = rubrica_preferences_get_user_dictionary();
      
      if (!dictionary)
	{
	  /* errore ancora non esiste dizionario */
	}
      else
	rubrica_dictionary_save_user_dictionary(client, dictionary);

      g_free(dictionary);
    }
}

void
on_show_rules_clicked  (GtkButton  *button, gpointer user_data)
{
  GtkWidget *w;

  w = create_translationbox();
  gtk_widget_show(w);
}

void on_show_column_check_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(key != NULL);
  
  /*    get ptr to the preferences window dialog and to the GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  /* get the new button state */
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  /* per queste chiavi sono necessarie altre operazioni 
     those keys needs other steps
  */

  /* store the new value */
  gconf_change_set_set_bool(cs, key, state);
  
  /* update preferences buttons sensitivity */
  rubrica_preferences_update_sensitivity(prefbox);

  /* update columns status */
  rubrica_addressbook_show_column_set(key, state);
}


void on_show_data_check_toggled(GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(key != NULL);
  
  /*    get ptr to the preferences window dialog and to the GConf change set
   */
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  /* get the new button state */
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  /* per queste chiavi sono necessarie altre operazioni 
     those keys needs other steps
  */

  /* store the new value */
  gconf_change_set_set_bool(cs, key, state);
  
  /* update preferences buttons sensitivity */
  rubrica_preferences_update_sensitivity(prefbox);

  /* update columns status */
//  rubrica_addressbook_show_column_set(key, state);



/*
  GtkWidget clist;
  gboolean bool;

  bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(user_data));

  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_NAME_PREFIX) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_TITLE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_BIRTHDAY) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_STREET) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_STREET_NUM) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_ZIP_CODE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_PROVINCE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_STATE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_COMPANY) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_STREET) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_CITY) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_WEB) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_EMAIL) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_OPERATOR) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_FAX) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_GREEN) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_NOTE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_ASSIGMENT) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_ORG) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_DEP) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_SUB_DEP) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_SECRETARY ) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_SECR_PHONE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_MARRIED) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_SPOUSE) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_CHILDREN) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH) == 0)
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_CHILD_NOTE) == 0)    
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTE) == 0)
*/
}




/*
void on_view_radio_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(key != NULL);

      get ptr to the preferences window dialog and to the GConf change set
  
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
   get the new button state 
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

   store the new value 
  gconf_change_set_set_bool(cs, key, state);

   update check buttons that are related to radio buttons
  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME) == 0)
    {
      rubrica_preferences_revert_personal_data(prefbox);
    }

  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL) == 0)
    {

      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_NAME_PREFIX);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_TITLE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_BIRTHDAY);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_STREET);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_STREET_NUM);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_ZIP_CODE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_PROVINCE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_STATE);

    }  

  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_SOME) == 0)
    {
       rubrica_preferences_revert_job_data(prefbox);
   }  

  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_JOB_ALL) == 0)
    {

      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_COMPANY);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_STREET);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_CITY);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_WEB);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_EMAIL);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_OPERATOR);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_FAX);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_GREEN);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_JOB_NOTE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_ASSIGMENT);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_ORG);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_DEP);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_SUB_DEP);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_SECRETARY);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_SECR_PHONE);  

    }  

  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTES_SOME) == 0)
    {
      rubrica_preferences_revert_notes_data(prefbox);
    }  

  if (strcmp(key, RUBRICA_KEY_SHOW_DATA_NOTES_ALL) == 0)
    {

      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_MARRIED);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_SPOUSE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_CHILDREN);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_CHILD_NOTE);
      rubrica_preferences_set_data(prefbox, RUBRICA_KEY_SHOW_DATA_NOTE);

    }  
  
   update preferences buttons sensitivity 
  rubrica_preferences_update_sensitivity(prefbox);
}

*/




/*
  void on_check_files_toggled (GtkToggleButton *togglebutton, gpointer user_data)
  {
  GtkWidget *prefbox; 
  GtkWidget *gentry;
  GtkWidget *entry;
  
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  gchar *key2;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);
  
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  if ((strcmp(key, RUBRICA_KEY_HAVE_BOOK) == 0))
  {
*/
/* get addressbook ptrs */
/*
  gentry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_BOOK);
  entry  = gtk_object_get_data(GTK_OBJECT(prefbox), "entry_addbook");
  key2   = g_strdup(RUBRICA_KEY_BOOK);
  }
  else
  {
*/
/* get folder ptrs */
/*
  gentry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_FOLDER);
  entry  = gtk_object_get_data(GTK_OBJECT(prefbox), "entry_folder");      
  key2   = g_strdup(RUBRICA_KEY_FOLDER);
  }
  
  if(!state)
  {      
  gtk_entry_set_text(GTK_ENTRY(entry), "");
  gconf_change_set_unset(cs, key2);      
  }
  
  gtk_widget_set_sensitive(gentry, state);
  
  gconf_change_set_set_bool(cs, key, state);
  
  g_free(key2); 
  }
  
void on_check_spin_toggled(GtkToggleButton *togglebutton, gpointer user_data)
  {
  GtkWidget *prefbox, *box, *spin; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);
  
  prefbox = rubrica_preferences_get_preferencesbox();
  
  cs   = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  box  = gtk_object_get_data(GTK_OBJECT(togglebutton), "spin_box");
  
  if (strcmp(key, RUBRICA_KEY_COMPRESS) == 0)
  spin = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_RATE);
  else
  spin = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_WAIT_TIME);
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));
  
  gtk_widget_set_sensitive(box, state);*/
//  gtk_widget_set_sensitive(spin, state);
/*
  gconf_change_set_set_bool(cs, key, state);
  
  if (!state)
  {
  gconf_change_set_set_bool(cs, key, FALSE);
  
  if (strcmp(key, RUBRICA_KEY_AUTOSAVE) == 0)
  gtk_timeout_add(0, (GtkFunction) rubrica_autosave, GINT_TO_POINTER(0));	
  }
  
  rubrica_preferences_update_sensitivity(prefbox);
  }
*/


/*
void on_radio_order_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;

  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);
*/
  /*    get ptr to preferences window dialog anto to GConf change set
   */
/*
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_ALPHA_ORDER) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ALPHA_ORDER, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DATE_ORDER, !state);
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ALPHA_ORDER, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DATE_ORDER, state);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}


void
on_radio_search_type_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);
*/
  /*    get ptr to preferences window dialog anto to GConf change set
   */
/*
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_COMPLETE) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_COMPLETE, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_INCOMPLETE, !state);
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_COMPLETE, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_INCOMPLETE, state);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}


void 
on_radio_backup_toggled(GtkToggleButton *button, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gint type;
  */
  /*    get ptr to preferences window dialog anto to GConf change set
   */
/*
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  type = GPOINTER_TO_INT(user_data);

  gconf_change_set_set_int(cs, RUBRICA_KEY_BACKUP_TYPE, type);  

  rubrica_preferences_update_sensitivity(prefbox); 
}
*/


/*
  witch dictionary will be used

  default (italian or english)

  external (user dictionary)
*/
/*
void
on_radio_witch_dict_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GtkWidget *radio_italian;
  GtkWidget *radio_english;
  GtkWidget *entry;
  GtkWidget *label_default;
  GtkWidget *label_language;
  GtkWidget *notebook;
  GtkWidget *label_io;
  GtkWidget *label_dict;
  GtkWidget *load;
  GtkWidget *save;
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);
*/
  /*    get ptr to preferences window dialog anto to GConf change set
   */
/*
  prefbox = rubrica_preferences_get_preferencesbox();

  load  = gtk_object_get_data(GTK_OBJECT(prefbox), "load");
  save  = gtk_object_get_data(GTK_OBJECT(prefbox), "save"); 
  entry = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_USER_DICTIONARY);
  notebook   = gtk_object_get_data(GTK_OBJECT(prefbox), "notebook_dict");
  label_io   = gtk_object_get_data(GTK_OBJECT(prefbox), "label_io");
  label_dict = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
  label_language = gtk_object_get_data(GTK_OBJECT(prefbox), "label_language");
  radio_italian  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ITALIAN);
  radio_english  = gtk_object_get_data(GTK_OBJECT(prefbox), RUBRICA_KEY_ENGLISH);
  label_default  = gtk_object_get_data(GTK_OBJECT(prefbox), "label_default_dict");
  
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_DEFAULT) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DEFAULT, state);
      gconf_change_set_set_bool(cs, RUBRICA_KEY_EXTERNAL, !state);  

      gtk_widget_set_sensitive(radio_italian, state);
      gtk_widget_set_sensitive(radio_english, state);
      gtk_widget_set_sensitive(label_default, state);

      gtk_widget_set_sensitive(entry, !state);
      gtk_widget_set_sensitive(label_language, !state);
      gtk_widget_set_sensitive(notebook, !state);
      gtk_widget_set_sensitive(label_io, !state);
      gtk_widget_set_sensitive(label_dict, !state);
      gtk_widget_set_sensitive(load, !state); 
      gtk_widget_set_sensitive(save, !state); 
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_DEFAULT, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_EXTERNAL, state);      

      gtk_widget_set_sensitive(radio_italian, !state);
      gtk_widget_set_sensitive(radio_english, !state);
      gtk_widget_set_sensitive(label_default, !state);

      gtk_widget_set_sensitive(entry, state);
      gtk_widget_set_sensitive(label_language, state);
      gtk_widget_set_sensitive(notebook, state);
      gtk_widget_set_sensitive(label_io, state);
      gtk_widget_set_sensitive(label_dict, state);
      gtk_widget_set_sensitive(load, state); 
      gtk_widget_set_sensitive(save, state); 
    }

  rubrica_preferences_update_sensitivity(prefbox);
}
*/

/*
  default dictionary that will be used
  
  italian (default)
  english
*/
/*
void
on_radio_dictionary_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gboolean state;
  gchar *key = user_data;
  
  g_return_if_fail(togglebutton != NULL);
  g_return_if_fail(user_data != NULL);
*/
  /*    get ptr to preferences window dialog anto to GConf change set
   */
/*
  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
  
  state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton));

  if ((strcmp(key, RUBRICA_KEY_ITALIAN) == 0))
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ITALIAN, state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ENGLISH, !state);
    }
  else
    {
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ITALIAN, !state);  
      gconf_change_set_set_bool(cs, RUBRICA_KEY_ENGLISH, state);      
    }

  rubrica_preferences_update_sensitivity(prefbox); 
} 
*/ 


/*
void on_entry_files_changed (GtkEditable *editable, gpointer user_data)
{
  GtkWidget *prefbox; 
  GConfChangeSet *cs;
  gchar *text;
  gchar *key = user_data;
  
  g_return_if_fail(editable != NULL);
  g_return_if_fail(user_data != NULL);  

  prefbox = rubrica_preferences_get_preferencesbox();
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");

  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
  
  if (*text != '\0')
    gconf_change_set_set_string(cs, key, text);
  else
    gconf_change_set_unset(cs, key);
  
  g_free(text);

  rubrica_preferences_update_sensitivity(prefbox);
}
*/


/*  callback richiamata ad ogni variazione
    dell'entry relativa al nome/linguaggio 
    del dizionario
*/
/*
void on_entry_user_lang_changed(GtkEditable *editable, gpointer user_data)
{  
  GtkWidget *prefbox; 
  GtkWidget *label;
  GConfChangeSet *cs;
  gchar *text;
  gchar *key = user_data;  
*/
  /*    get ptr to configuration dialog    */
/*
  prefbox = rubrica_preferences_get_preferencesbox();
*/
  /*    get ptr to GConf ChangeSet  */
/*
  cs = gtk_object_get_data(GTK_OBJECT(prefbox), "changeset");
*/
  /*     get the ptr to the label that show the dictionary file name, 
	 clear it, 
	 get the text typed into entry 
  */
/*
  label = gtk_object_get_data(GTK_OBJECT(prefbox), "label_dict_name");
  gtk_label_set_pattern(GTK_LABEL(label), NULL);
  text = gtk_editable_get_chars(GTK_EDITABLE(editable), 0, -1);
*/
  /*    if text was entered show it into label, and set into changeset
   */
/*
  if (strlen(text) > 0)
    {
      gtk_label_set_text(GTK_LABEL(label), text);
      rubrica_preferences_set_user_dictionary(text);
      
      gconf_change_set_set_string(cs, key, text);
    }
  else
    {
      gtk_label_set_text(GTK_LABEL(label), "");
      
      gconf_change_set_unset(cs, key);      
    }

  rubrica_preferences_update_sensitivity(prefbox);
}
*/

