/*
*  program name: Rubrica -- http://digilander.iol.it/nfragale/download.html
*  file: prefer_int.c
*  
*  build the graphic interface for preferences dialog
*
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <gconf/gconf-client.h>
#include <gconf/gconf-value.h>
#include <gconf/gconf-schema.h>
#include <gnome.h>

#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer.h"
#include "prefer-configure.h"
#include "prefer-notify.h"
#include "support.h"
#include "dialoghi.h"
#include "error.h"


static GtkWidget* preferences_dialog = NULL;
static GtkWidget* notebook = NULL;
GtkTooltips* tooltips;

/*
gchar *categorie[][] = {
  { NULL, _("birthday"),    NULL },
  { NULL, _("business"),    NULL },
  { NULL, _("favorites"),   NULL },
  { NULL, _("goals"),       NULL },
  { NULL, _("holiday"),     NULL },
  { NULL, _("personal"),    NULL },
  { NULL, _("strategies"),  NULL },
  { NULL, _("hart"),        NULL },
  { NULL, _("friends"),     NULL },
  { NULL, _("pictures"),    NULL },
  { NULL, _("nature"),      NULL },
  { NULL, _("sea"),         NULL },
  { NULL, _("mount"),       NULL },
  { NULL, _("programmers"), NULL }
};
*/


GtkWidget* rubrica_preferences_get_preferencesbox(void)
{
  return (GtkWidget*) preferences_dialog;
}


GtkWidget* rubrica_preferences_get_notebook(void)
{
  return (GtkWidget*) notebook;
}


GtkWidget*
create_preferences_dialog (GConfClient *client)
{
  GConfChangeSet *cs;

  GtkWidget *dialog_vbox;
  GtkWidget *dialog_action_area2;

  GtkWidget *ok;
  GtkWidget *apply;
  GtkWidget *revert;
  GtkWidget *close;

  GtkWidget *frame;
  GtkWidget *tab;

  preferences_dialog = gnome_dialog_new (_("Rubrica Preferences"), NULL);
  notebook           = gtk_notebook_new ();
  tooltips           = gtk_tooltips_new ();
  cs                 = gconf_change_set_new();

  rubrica_preferences_reset_errors();

  gtk_widget_set_name (preferences_dialog, "preferences_dialog");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "preferences_dialog", 
		       preferences_dialog);
  GTK_WINDOW (preferences_dialog)->type = GTK_WINDOW_DIALOG;
  gtk_window_set_position (GTK_WINDOW (preferences_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (preferences_dialog), TRUE);
  gtk_window_set_policy (GTK_WINDOW (preferences_dialog), FALSE, FALSE, FALSE);

  gtk_widget_set_name (notebook, "notebook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "notebook", notebook);

  dialog_vbox = GNOME_DIALOG (preferences_dialog)->vbox;
  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 2);
  gtk_widget_show (dialog_vbox);

  gtk_box_pack_start (GTK_BOX (dialog_vbox), notebook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (notebook), 2);

  /*      Notebook's pages configuration 
	  Add here new pages
	  --------------------------------------------------------
  */
  frame = rubrica_preferences_add_files_page(client);
  tab   = gtk_label_new (_(" File "));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);

  frame = rubrica_preferences_add_general_page(client);
  tab = gtk_label_new (_(" General "));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);

  frame = rubrica_preferences_add_view_page(client);
  tab   = gtk_label_new (_(" View "));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);

  frame = rubrica_preferences_add_translation_page(client);
  tab   = gtk_label_new (_(" Translation "));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);


  /*      -------------------------------------------------------- 
  */  

  gtk_widget_show (notebook);

  if (rubrica_preferences_there_are_errors())
    {
      gtk_window_set_modal (GTK_WINDOW (preferences_dialog), FALSE);
      rubrica_error_loading_preferences_keys();      
      gtk_window_set_modal (GTK_WINDOW (preferences_dialog), TRUE);      
    }

  dialog_action_area2 = GNOME_DIALOG (preferences_dialog)->action_area;
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);
  gtk_button_box_set_spacing (GTK_BUTTON_BOX (dialog_action_area2), 5);
  gtk_button_box_set_child_size (GTK_BUTTON_BOX (dialog_action_area2), 80, 27);
  gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (dialog_action_area2), 5, 0);
  gtk_widget_show (dialog_action_area2);

  gnome_dialog_append_button (GNOME_DIALOG (preferences_dialog), 
			      GNOME_STOCK_BUTTON_OK);
  ok = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (ok, GTK_CAN_DEFAULT);
  gtk_widget_set_name (ok, "ok");
  gtk_widget_show (ok);

  gnome_dialog_append_button (GNOME_DIALOG (preferences_dialog), 
			      GNOME_STOCK_BUTTON_APPLY);
  apply = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (apply, GTK_CAN_DEFAULT);
  gtk_widget_show (apply);

  gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (preferences_dialog),
                                          _("Revert"), GNOME_STOCK_PIXMAP_REVERT);
  revert = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (revert, GTK_CAN_DEFAULT);
  gtk_widget_show (revert);

  gnome_dialog_append_button (GNOME_DIALOG (preferences_dialog), 
			      GNOME_STOCK_BUTTON_CLOSE);
  close = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (close, GTK_CAN_DEFAULT);
  gtk_widget_show (close);

  gtk_widget_set_sensitive(ok, FALSE);
  gtk_widget_set_sensitive(apply, FALSE);
  gtk_widget_set_sensitive(revert, FALSE);

  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "ok", ok);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "apply", apply);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "revert", revert);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "close", close);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "client", client);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "tooltips", tooltips);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "changeset", cs);

  /*    Callbacks
  */
  gtk_signal_connect (GTK_OBJECT (ok), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_ok_clicked),
                      preferences_dialog);

  gtk_signal_connect (GTK_OBJECT (apply), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_apply_clicked),
                      preferences_dialog);

  gtk_signal_connect (GTK_OBJECT (revert), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_revert_clicked),
                      preferences_dialog);

  gtk_signal_connect (GTK_OBJECT (close), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_close_dialog), 
                      preferences_dialog); 

  return preferences_dialog;
}



GtkWidget *rubrica_preferences_add_files_page(GConfClient *client)
{
  GtkWidget *file_frame;

  GtkWidget *box_file;
  GtkWidget *table_show;
  GtkWidget *box_addbook;
  GtkWidget *box_folder;
  GtkWidget *box_backup;
  GtkWidget *box_radio_backup;
  GtkWidget *box_main_compress;
  GtkWidget *box_compression;
  GtkWidget *box_compression_rate;
  GtkWidget *box_autosave;
  GtkWidget *box_check_autosave;
  GtkWidget *box_spin_autosave;

  GtkWidget *show_frame;
  GtkWidget *addbook_frame;
  GtkWidget *folder_frame;
  GtkWidget *backup_frame;
  GtkWidget *compress_frame;
  GtkWidget *autosave_frame;

  GSList *radio_backup_group = NULL;
  GtkWidget *radio_backup_inc;
  GtkWidget *radio_backup_classic;

  GtkWidget *check_path;
  GtkWidget *check_addbook;
  GtkWidget *check_folder;
  GtkWidget *check_backup;
  GtkWidget *check_compress;
  GtkWidget *check_autosave;

  GtkWidget *fileentry_addbook;
  GtkWidget *fileentry_folder;
  GtkWidget *entry_addbook;
  GtkWidget *entry_folder;

  GtkWidget *label_compress_rate;
  GtkObject *spin_rate_adj;
  GtkWidget *spin_rate;

  GtkWidget *label_autosave1;
  GtkWidget *label_autosave2;
  GtkObject *spin_autosave_adj;
  GtkWidget *spin_autosave;

  gchar *home, *str;


  file_frame = gtk_frame_new (_(" Files settings "));
  gtk_container_set_border_width (GTK_CONTAINER (file_frame), 2);
  gtk_widget_show (file_frame);

  box_file = gtk_vbox_new (FALSE, 2);
  gtk_widget_show (box_file);
  gtk_container_add (GTK_CONTAINER (file_frame), box_file);

  show_frame = gtk_frame_new (_(" Show "));
  gtk_widget_show (show_frame);
  gtk_box_pack_start (GTK_BOX (box_file), show_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (show_frame), 2);

  table_show = gtk_table_new (1, 1, TRUE);
  gtk_widget_show (table_show);
  gtk_container_add (GTK_CONTAINER (show_frame), table_show);
  gtk_container_set_border_width (GTK_CONTAINER (table_show), 2);

  /*    Show:
	- by default, only file name is show
	- check to show path too

	CHECK BUTTON:
	SHOW FILE
  */
  check_path = gtk_check_button_new_with_label (_("Show addressbook's path"));
  gtk_widget_set_name (check_path, "check_path");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW, check_path);
  gtk_widget_show (check_path);

  gtk_table_attach (GTK_TABLE (table_show), check_path, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_path), 2);
  gtk_tooltips_set_tip (tooltips, check_path, 
			_("Show the path of current addressbook "), NULL);

  /* ---------------------------------------------------------------------
     GConf settings 
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_path, client, RUBRICA_KEY_SHOW);

  /* ---------------------------------------------------------------------  */
  
  /*    -----------------------------------------------------------------------
	load Address book at rubrica start
	use a default folder to save addressbooks

	- check_addbook   
	    - true:  load addressbook at start
	    - false: start with void addressbook

	    - entry: addressbook file name
	
	- check_folder
	    - true:  use the setted directory as default folder
	    - false  save addressbook in current directory

	    - entry: directory name
	-----------------------------------------------------------------------
  */
  addbook_frame = gtk_frame_new (_(" Default address book "));
  gtk_box_pack_start (GTK_BOX (box_file), addbook_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (addbook_frame), 2);
  gtk_widget_show (addbook_frame);

  box_addbook = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (addbook_frame), box_addbook);
  gtk_widget_show (box_addbook);

  /*    CHECK BUTTON
	CHECK ADDRESS BOOK
   */
  check_addbook = gtk_check_button_new_with_label(_("Load this addressbook at start"));
  gtk_widget_set_name (check_addbook, "check_addbook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_HAVE_BOOK,
		       check_addbook);
  gtk_box_pack_start (GTK_BOX (box_addbook), check_addbook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_addbook), 2);
  gtk_widget_show (check_addbook);

  /*    GNOME FILE ENTRY
	ADDRESS BOOK
  */
  fileentry_addbook = gnome_file_entry_new ("histoty_start", NULL);
  gtk_widget_set_name (fileentry_addbook, "fileentry_addbook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_BOOK, 
		       fileentry_addbook);
  gtk_box_pack_start (GTK_BOX (box_addbook), fileentry_addbook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry_addbook), 2);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry_addbook), TRUE);
  gtk_widget_show (fileentry_addbook);

  /*    FILE ENTRY
	ADDRESS BOOK
  */  
  home = g_get_home_dir();
  str = g_strdup_printf("%s/.rubrica/rubrica.rub", home);
  entry_addbook = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (fileentry_addbook));
  gtk_widget_set_name (entry_addbook, "entry_addbook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_addbook", 
		       entry_addbook);
  gtk_entry_set_text (GTK_ENTRY (entry_addbook), str);
  gtk_widget_show (entry_addbook);
  g_free(home);
  g_free(str);  

  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_checked_entry(check_addbook, fileentry_addbook,
					      entry_addbook, client,
					      RUBRICA_KEY_HAVE_BOOK, 
					      RUBRICA_KEY_BOOK);
  /*    ---------------------------------------------------------------------  */

//  str2 = g_strdup(_(" Default folder "));
  folder_frame = gtk_frame_new (_(" Default folder "));
  gtk_box_pack_start (GTK_BOX (box_file), folder_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (folder_frame), 2);
  gtk_widget_show (folder_frame);

  box_folder = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (folder_frame), box_folder);
  gtk_widget_show (box_folder);

  /*    CHECK FOLDER
   */
  check_folder = gtk_check_button_new_with_label 
    (_("Save addressbooks in this folder by default"));
  gtk_widget_set_name (check_folder, "check_folder");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_HAVE_FOLDER, 
		       check_folder);
  gtk_box_pack_start (GTK_BOX (box_folder), check_folder, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_folder), 2);
  gtk_widget_show (check_folder);

  /*    GNOME FILE ENTRY
	FOLDER
  */
  fileentry_folder = gnome_file_entry_new ("history_folder", _("Choose a folder"));
  gtk_widget_set_name (fileentry_folder, "fileentry_folder");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_FOLDER, 
		       fileentry_folder);
  gtk_box_pack_start (GTK_BOX (box_folder), fileentry_folder, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry_folder), 2);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry_folder), TRUE);
  gtk_widget_show (fileentry_folder);

  /*    FILE ENTRY
	FOLDER
  */ 
  home = g_get_home_dir();
  str = g_strdup_printf("%s/.rubrica/", home);  
  entry_folder = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (fileentry_folder));
  gtk_widget_set_name (entry_folder, "entry_folder");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_folder", 
		       entry_folder);
  gtk_widget_show (entry_folder);
  gtk_entry_set_text (GTK_ENTRY (entry_folder), str);
  g_free(home);
  g_free(str);  

  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_checked_entry(check_folder, fileentry_folder,
					      entry_folder, client, 
					      RUBRICA_KEY_HAVE_FOLDER,
					      RUBRICA_KEY_FOLDER);
  /*    ---------------------------------------------------------------------  */

  /*    Backup:
	- do backup before overwrite 

	default: don't do backup

	CHECK BUTTON
	BACKUP ALWAYS
  */ 
  backup_frame = gtk_frame_new (_(" Backup "));
  gtk_box_pack_start (GTK_BOX (box_file), backup_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (backup_frame), 2);
  gtk_widget_show (backup_frame);

  box_backup = gtk_hbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (backup_frame), box_backup);
  gtk_container_set_border_width (GTK_CONTAINER (box_backup), 2);
  gtk_widget_show (box_backup);

  /*    CHECK BUTTON BACKUP 
  */
  check_backup = gtk_check_button_new_with_label 
    (_("Make backup of previous file before overwrite"));
  gtk_widget_set_name (check_backup, "check_backup");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_BACKUP, 
		       check_backup);
  gtk_box_pack_start (GTK_BOX (box_backup), check_backup, TRUE, TRUE, 0);
  gtk_widget_show (check_backup);

  /*    RADIO BACKUP INCREMENT
  */
  box_radio_backup = gtk_hbox_new (FALSE, 0);
  gtk_box_pack_start (GTK_BOX (box_backup), box_radio_backup, FALSE, FALSE, 0);
  gtk_widget_show (box_radio_backup);

  radio_backup_inc = gtk_radio_button_new_with_label (radio_backup_group,
						      _("incremental backup"));
  radio_backup_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_backup_inc));

  gtk_widget_set_name (radio_backup_inc, "inc_bak");
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), "inc_bak", 
		      radio_backup_inc);

  gtk_box_pack_start (GTK_BOX (box_radio_backup), radio_backup_inc, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_backup_inc, 
			_("Example: add.rub's backup will be add.rub1, if add.rub1 exist then backup will be add.rub2, and so on."),
			NULL);
  gtk_widget_show (radio_backup_inc);

  /*    RADIO BACKUP CLASSIC
  */
  radio_backup_classic = gtk_radio_button_new_with_label (radio_backup_group, 
							  _("classic backup"));
  radio_backup_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_backup_classic));

  gtk_widget_set_name (radio_backup_classic, "bak_bak");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),"bak_bak", 
		       radio_backup_classic);

  gtk_box_pack_start (GTK_BOX (box_radio_backup), radio_backup_classic, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_backup_classic, 
			_("add.rub's backup will be add.bak"), NULL);
  gtk_widget_show (radio_backup_classic);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check_radio(check_backup, radio_backup_inc,
					    radio_backup_classic, client, 
					    RUBRICA_KEY_BACKUP,
					    RUBRICA_KEY_BACKUP_TYPE_INC);
  /*    ---------------------------------------------------------------------  */


  /*    Compress addressbook:
	- compression check button        
	- compression rate spin button

	default: not zip, compression rate: 0

	CHECK BUTTON
	COMPRESS ADDRESSBOOK FILE
  */
  compress_frame = gtk_frame_new (_(" Compression "));
  gtk_box_pack_start (GTK_BOX (box_file), compress_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (compress_frame), 2);
  gtk_widget_show (compress_frame);

  box_main_compress = gtk_vbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (compress_frame), box_main_compress);
  gtk_container_set_border_width (GTK_CONTAINER (box_main_compress), 2);
  gtk_widget_show (box_main_compress);

  box_compression = gtk_hbox_new (TRUE, 0);
  gtk_box_pack_start (GTK_BOX (box_main_compress), box_compression, FALSE, FALSE, 0);
  gtk_widget_show (box_compression);

  /*    CHECK BUTTON COMPRESS ADDRESSBOOK FILE
  */
  check_compress = gtk_check_button_new_with_label (_("Compress addressbook"));
  gtk_widget_set_name (check_compress, RUBRICA_KEY_COMPRESS);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_COMPRESS, 
		       check_compress);
  gtk_box_pack_start (GTK_BOX (box_compression), check_compress, TRUE, TRUE, 0);
  gtk_widget_show (check_compress);

  box_compression_rate = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (box_compression_rate, "box_compression_rate");
  gtk_box_pack_end(GTK_BOX(box_main_compress), box_compression_rate, FALSE, FALSE, 0);
  gtk_widget_show (box_compression_rate);

  gtk_object_set_data (GTK_OBJECT (check_compress), "spin_box", box_compression_rate);

  label_compress_rate = gtk_label_new (_("Compression rate:"));
//  gtk_widget_set_name (label_compress_rate, "label_compress_rate");
//  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_compress_rate", 
//		       label_compress_rate);
  gtk_box_pack_start(GTK_BOX(box_compression_rate),label_compress_rate,FALSE,TRUE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_compress_rate), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_compress_rate), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_compress_rate), 3, 0);
  gtk_widget_show (label_compress_rate);

  /*    SPIN BUTTON
	COMPRESSION RATE
  */  
  spin_rate_adj = gtk_adjustment_new (0, 0, 9, 1, 1, 1);
  spin_rate = gtk_spin_button_new (GTK_ADJUSTMENT (spin_rate_adj), 1, 0);

  gtk_widget_set_name (spin_rate, RUBRICA_KEY_RATE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_RATE, spin_rate);

  gtk_box_pack_start (GTK_BOX (box_compression_rate), spin_rate, FALSE, FALSE, 68);
  gtk_tooltips_set_tip (tooltips, spin_rate,
			_("0 not compressed, 9 max compression rate"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin_rate), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spin_rate), FALSE);
  gtk_widget_show (spin_rate);

  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_spin(check_compress, spin_rate, client, 
				     RUBRICA_KEY_COMPRESS,
				     RUBRICA_KEY_RATE);
  /*    ---------------------------------------------------------------------  */

  /*    Automatic save:
	- autosave check button        
	- autosave spin button

	default: autosave no, time elapsed: 0

	CHECK BUTTON
	AUTOSAVE ADDRESSBOOK FILE
  */
  autosave_frame = gtk_frame_new (_(" Autosave "));
  gtk_container_set_border_width (GTK_CONTAINER (autosave_frame), 2);
  gtk_widget_show (autosave_frame);
  gtk_box_pack_start (GTK_BOX (box_file), autosave_frame, FALSE, FALSE, 2);

  box_autosave = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (autosave_frame), box_autosave);
  gtk_container_set_border_width (GTK_CONTAINER (box_autosave), 2);
  gtk_widget_show (box_autosave);

  box_check_autosave = gtk_hbox_new (FALSE, 0);
  gtk_box_pack_start (GTK_BOX (box_autosave), box_check_autosave, FALSE, FALSE, 0);
  gtk_widget_show (box_check_autosave);

  /*    CHECK BUTTON AUTOSAVE ADDRESSBOOK FILE
  */
  check_autosave = gtk_check_button_new_with_label (_("enable autosave"));
  gtk_widget_set_name (check_autosave, RUBRICA_KEY_AUTOSAVE);
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), RUBRICA_KEY_AUTOSAVE,
		      check_autosave);
  gtk_box_pack_start (GTK_BOX (box_check_autosave), check_autosave, TRUE, TRUE, 0);
  gtk_widget_show (check_autosave);

  box_spin_autosave = gtk_hbox_new (FALSE, 0);

  gtk_widget_set_name (box_spin_autosave, "spin_box");
  gtk_object_set_data(GTK_OBJECT (check_autosave), "spin_box", box_spin_autosave);

  gtk_box_pack_start (GTK_BOX (box_autosave), box_spin_autosave, FALSE, FALSE, 0);
  gtk_widget_show (box_spin_autosave);

  label_autosave1 = gtk_label_new (_("Save addressbooks ever "));
  gtk_box_pack_start (GTK_BOX (box_spin_autosave), label_autosave1, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label_autosave1), 3, 0);
  gtk_widget_show (label_autosave1);

  /*    SPIN BUTTON
	SAVE EVERY xx MINUTES
  */  
  spin_autosave_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 10);
  spin_autosave = gtk_spin_button_new (GTK_ADJUSTMENT (spin_autosave_adj), 1, 0);

  gtk_widget_set_name (spin_autosave, RUBRICA_KEY_WAIT_TIME);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_WAIT_TIME, 
		       spin_autosave);

  gtk_widget_show (spin_autosave);
  gtk_box_pack_start (GTK_BOX (box_spin_autosave), spin_autosave, FALSE, FALSE, 0);

  label_autosave2 = gtk_label_new (_(" minutes"));
  gtk_box_pack_start (GTK_BOX (box_spin_autosave), label_autosave2, FALSE, FALSE, 0);
  gtk_widget_show (label_autosave2);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_spin(check_autosave, spin_autosave, client, 
				     RUBRICA_KEY_AUTOSAVE,
				     RUBRICA_KEY_WAIT_TIME);
  gconf_client_notify_add(client, RUBRICA_KEY_WAIT_TIME, 
			  rubrica_autosave_time_changed_notify, 
			  spin_autosave, NULL, NULL);
  /*    ---------------------------------------------------------------------  */



  /*    SHOW PATH CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_path), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_SHOW);

  /*    LOAD DEFAULT ADDRESS BOOK CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (check_addbook), "toggled",
                       GTK_SIGNAL_FUNC (on_check_button_toggled),
//                     GTK_SIGNAL_FUNC (on_check_files_toggled),
		      RUBRICA_KEY_HAVE_BOOK);
  gtk_signal_connect (GTK_OBJECT (entry_addbook), "changed",
		      GTK_SIGNAL_FUNC (on_entry_changed),
//		      GTK_SIGNAL_FUNC (on_entry_files_changed),
                      RUBRICA_KEY_BOOK);
  
  /*    USE DEFAULT FOLDER CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (check_folder), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
//                      GTK_SIGNAL_FUNC (on_check_files_toggled),
		      RUBRICA_KEY_HAVE_FOLDER);
  gtk_signal_connect (GTK_OBJECT (entry_folder), "changed",
		      GTK_SIGNAL_FUNC (on_entry_changed),
//                      GTK_SIGNAL_FUNC (on_entry_files_changed),
                      RUBRICA_KEY_FOLDER);

  /*    BACKUP CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (check_backup), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_BACKUP);

  gtk_signal_connect (GTK_OBJECT (radio_backup_inc), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_backup_toggled),
                      RUBRICA_KEY_BACKUP_TYPE_INC);
  gtk_signal_connect (GTK_OBJECT (radio_backup_classic), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_backup_toggled),
                      RUBRICA_KEY_BACKUP_TYPE_BAK);

  /*    COMPRESS CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (check_compress), "toggled",
                       GTK_SIGNAL_FUNC (on_check_button_toggled),
//                     GTK_SIGNAL_FUNC (on_check_spin_toggled),
		      RUBRICA_KEY_COMPRESS);
  gtk_signal_connect (GTK_OBJECT (spin_rate), "activate",
                      GTK_SIGNAL_FUNC (on_spin_activate),
                      RUBRICA_KEY_RATE);
  gtk_signal_connect (GTK_OBJECT (spin_rate), "changed",
                      GTK_SIGNAL_FUNC (on_spin_activate),
                      RUBRICA_KEY_RATE);

  /*    AUTOSAVE CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (check_autosave), "toggled",
                       GTK_SIGNAL_FUNC (on_check_button_toggled),
//                     GTK_SIGNAL_FUNC (on_check_spin_toggled),
		      RUBRICA_KEY_AUTOSAVE);
  gtk_signal_connect (GTK_OBJECT (spin_autosave), "activate",
                      GTK_SIGNAL_FUNC (on_spin_activate),
                      RUBRICA_KEY_WAIT_TIME);
  gtk_signal_connect (GTK_OBJECT (spin_autosave), "changed",
                      GTK_SIGNAL_FUNC (on_spin_activate),
                      RUBRICA_KEY_WAIT_TIME);

  return (GtkWidget *) file_frame;
}



GtkWidget *rubrica_preferences_add_general_page(GConfClient *client)
{
  GtkWidget *general_frame;

  GtkWidget *box_general;
  GtkWidget *box_order;
  GtkWidget *box_search;
  GtkWidget *box_exit;
  GtkWidget *box_tips;

  GtkWidget *table1;
  GtkWidget *search_table;

  GSList *opt_ordine_group = NULL;
  GSList *opt_string_search_group = NULL;

  GtkWidget *radio_complete;
  GtkWidget *radio_incomplete;

  GtkWidget *ordering_frame;
  GtkWidget *search_frame;
  GtkWidget *exit_frame;
  GtkWidget *tips_frame;

  GtkWidget *radio_alpha;
  GtkWidget *radio_date;

  GtkWidget *check_increase;
  GtkWidget *check_case_search;
  GtkWidget *check_exit;
  GtkWidget *check_tips;

  GtkWidget *label_show;
  GtkWidget *label_search; 
  GtkWidget *label_search_menu;

  GtkWidget *combo_search;
  GList *combo_search_items = NULL;
  GtkWidget *combo_entry_search;


//  general_frame = gtk_frame_new (_("General"));
  general_frame = gtk_frame_new (" General ");
  gtk_container_set_border_width (GTK_CONTAINER (general_frame), 2);
  gtk_widget_show (general_frame);

  box_general = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (general_frame), box_general);
  gtk_container_set_border_width (GTK_CONTAINER (box_general), 2);
  gtk_widget_show (box_general);

  /*    Ordering:
	- increasing   (true)
	- decreasing   (false)

	default: increasing 
  */
  ordering_frame = gtk_frame_new (_(" Ordering "));
  gtk_box_pack_start (GTK_BOX (box_general), ordering_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (ordering_frame), 2);
  gtk_widget_show (ordering_frame);

  box_order = gtk_vbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (ordering_frame), box_order);
  gtk_container_set_border_width (GTK_CONTAINER (box_order), 2);
  gtk_widget_show (box_order);

  table1 = gtk_table_new (2, 3, TRUE);
  gtk_widget_show (table1);

  gtk_box_pack_start (GTK_BOX (box_order), table1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 5);

  label_show = gtk_label_new (_("Show cards:  "));
  gtk_widget_show (label_show);

  gtk_table_attach (GTK_TABLE (table1), label_show, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_show), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label_show), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_show), 1.93715e-07, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_show), 5, 0);

  /* 
     CHECK BUTTON: INCREASE
  */
  check_increase = gtk_check_button_new_with_label (_("Ordering is increasing"));
  gtk_widget_set_name (check_increase, "check_increase");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_INCREASE, 
		       check_increase);
  gtk_table_attach (GTK_TABLE (table1), check_increase, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_increase), 2);
  gtk_tooltips_set_tip (tooltips, check_increase, 
			_("Uncheck for decreasing ordering"), NULL);
  gtk_widget_show (check_increase);

  /* ---------------------------------------------------------------------
     GConf settings
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_increase, client, RUBRICA_KEY_INCREASE); 
  /* ---------------------------------------------------------------------  */

  /*        RADIO BUTTONS

            - ORDER BY DATE
	    - ORDER ALPHABETIC

	    default: alphabetic order
  */
  radio_date = gtk_radio_button_new_with_label (opt_ordine_group, 
						_("by creation date"));
  opt_ordine_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_date));
  gtk_widget_set_name (radio_date, "radio_date");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_DATE_ORDER, 
		       radio_date);
  gtk_table_attach (GTK_TABLE (table1), radio_date, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_date);

  radio_alpha = gtk_radio_button_new_with_label (opt_ordine_group, 
						 _("in alphabetic order"));
  opt_ordine_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_alpha));
  gtk_widget_set_name (radio_alpha, "radio_alpha");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_ALPHA_ORDER,  
		       radio_alpha);
  gtk_table_attach (GTK_TABLE (table1), radio_alpha, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_alpha);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(radio_alpha, radio_date, client, 
				      RUBRICA_KEY_ALPHA_ORDER,
				      RUBRICA_KEY_DATE_ORDER);
  /*    ---------------------------------------------------------------------  */

  search_frame = gtk_frame_new (_(" Search "));
  gtk_box_pack_start (GTK_BOX (box_general), search_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (search_frame), 2);
  gtk_widget_show (search_frame);

  box_search = gtk_vbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (search_frame), box_search);
  gtk_container_set_border_width (GTK_CONTAINER (box_search), 2);
  gtk_widget_show (box_search);

  search_table = gtk_table_new (3, 3, TRUE);
  gtk_box_pack_start (GTK_BOX (box_search), search_table, TRUE, TRUE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (search_table), 5);
  gtk_widget_show (search_table);

  label_search = gtk_label_new (_("Search on:"));
  gtk_widget_show (label_search);
  gtk_table_attach (GTK_TABLE (search_table), label_search, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_search), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label_search), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_search), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search), 4, 0);

  /*      CHECK BUTTON
	  
          SEARCH CASE SENSITIVE
  */
  check_case_search = gtk_check_button_new_with_label 
    (_("Default search is case sensitive"));
  gtk_widget_set_name (check_case_search, "check_case_search");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "check_case_search",
		       check_case_search);
  gtk_table_attach (GTK_TABLE (search_table), check_case_search, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_case_search), 2);
  gtk_tooltips_set_tip (tooltips, check_case_search, 
			_("Uncheck for case insensitive search"), NULL);
  gtk_widget_show (check_case_search);

  /*        RADIO BUTTONS
	    
            - SEARCH ON COMPLETE STRING
	    - SEARCH ON INCOMPLETE STRING     

	    default: search in complete string
   */
  radio_complete = gtk_radio_button_new_with_label (opt_string_search_group, 
						    _("complete string"));
  opt_string_search_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_complete));
  gtk_widget_set_name (radio_complete, "radio_complete");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_COMPLETE, 
		       radio_complete);
  gtk_table_attach (GTK_TABLE (search_table), radio_complete, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_complete);

  radio_incomplete = gtk_radio_button_new_with_label (opt_string_search_group, 
						      _("incomplete string"));
  opt_string_search_group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_incomplete));
  gtk_widget_set_name (radio_incomplete, "radio_incomplete");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_INCOMPLETE, 
		       radio_incomplete);
  gtk_table_attach (GTK_TABLE (search_table), radio_incomplete, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_incomplete);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(radio_complete, radio_incomplete, client, 
				      RUBRICA_KEY_COMPLETE,
				      RUBRICA_KEY_INCOMPLETE);
  /*    ---------------------------------------------------------------------  */


  label_search_menu = gtk_label_new (_("Default Search on: "));
  gtk_widget_show (label_search_menu);
  gtk_table_attach (GTK_TABLE (search_table), label_search_menu, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_search_menu), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label_search_menu), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_search_menu), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search_menu), 4, 0);


  /*    COMBO SEARCH -- Display all searchable data --
  */
  combo_search = gtk_combo_new ();
  gtk_widget_set_name (combo_search, RUBRICA_KEY_SEARCH);
  gtk_object_set_data (GTK_OBJECT(preferences_dialog), RUBRICA_KEY_SEARCH, 
		       combo_search);
  gtk_widget_show (combo_search);
  gtk_table_attach (GTK_TABLE (search_table), combo_search, 1, 2, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  gtk_combo_set_value_in_list (GTK_COMBO (combo_search), TRUE, FALSE);
  
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_CARD);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_FIRST_NAME);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_LAST_NAME);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_PROFESSION);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_CITY);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_COUNTRY);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_WEB_ADDRESS);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_EMAIL_ADDRESS);
  combo_search_items = g_list_append (combo_search_items, RUBRICA_SEARCH_TELEPHONE);
  gtk_combo_set_popdown_strings (GTK_COMBO (combo_search), combo_search_items);
  g_list_free (combo_search_items);
  
  combo_entry_search = GTK_COMBO (combo_search)->entry;
  gtk_widget_set_name (combo_entry_search, "entry_search");
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), "entry_search", 
		      combo_entry_search);
  gtk_widget_show (combo_entry_search);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_combo_entry(combo_entry_search, client, 
					    RUBRICA_KEY_SEARCH);
  /*    ---------------------------------------------------------------------  */

  /*    ***********************************************
   */
  exit_frame = gtk_frame_new (_(" Exit "));
  gtk_box_pack_start (GTK_BOX (box_general), exit_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (exit_frame), 2);
  gtk_widget_show (exit_frame);

  box_exit = gtk_hbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (exit_frame), box_exit);
  gtk_container_set_border_width (GTK_CONTAINER (box_exit), 2);
  gtk_widget_show (box_exit);

  /*    CHECK BUTTON
	
	EXIT

	default: ask before quit
  */
  check_exit = gtk_check_button_new_with_label(_("Exit from rubrica without confirm"));
  gtk_widget_set_name (check_exit, "check_exit");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_EXIT, check_exit);
  gtk_box_pack_start (GTK_BOX (box_exit), check_exit, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_exit), 2);
  gtk_widget_show (check_exit);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_exit, client, RUBRICA_KEY_EXIT);
  /*    ---------------------------------------------------------------------  */

  tips_frame = gtk_frame_new (_(" Tips "));
  gtk_widget_set_name (tips_frame, "tips_frame");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "tips_frame", tips_frame);
  gtk_box_pack_start (GTK_BOX (box_general), tips_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (tips_frame), 2);
  gtk_widget_show (tips_frame);

  box_tips = gtk_hbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (tips_frame), box_tips);
  gtk_container_set_border_width (GTK_CONTAINER (box_tips), 2);
  gtk_widget_show (box_tips);

  /*    CHECK BUTTON
	
	SHOW TIPS
	
	default: show tips at startup
  */
  check_tips = gtk_check_button_new_with_label (_("Show tips at rubrica start"));
  gtk_widget_set_name (check_tips, "check_tips");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_TIPS, check_tips);
  gtk_box_pack_start (GTK_BOX (box_tips), check_tips, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_tips), 2);
  gtk_widget_show (check_tips);

  gtk_widget_set_sensitive(check_tips, FALSE);

  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_tips, client, RUBRICA_KEY_TIPS);
  /*    ---------------------------------------------------------------------  */

  /*    INCREASE CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_increase), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_INCREASE);

  /*    ORDERING TYPE CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (radio_alpha), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_order_toggled),
                      RUBRICA_KEY_ALPHA_ORDER);
  gtk_signal_connect (GTK_OBJECT (radio_date), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_order_toggled),
		      RUBRICA_KEY_DATE_ORDER);

  /*    SEARCH CALLBACS
  */
  gtk_signal_connect (GTK_OBJECT (check_case_search), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_SENSITIVE);

  gtk_signal_connect (GTK_OBJECT (radio_complete), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_search_type_toggled),
                      RUBRICA_KEY_COMPLETE);
  gtk_signal_connect (GTK_OBJECT (radio_incomplete), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_search_type_toggled),
		      RUBRICA_KEY_INCOMPLETE);

  gtk_signal_connect (GTK_OBJECT (combo_entry_search), "changed",
                      GTK_SIGNAL_FUNC (on_entry_search_changed), 
                      RUBRICA_KEY_SEARCH); 


  /*    EXIT CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_exit), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_EXIT);

  /*      TIPS CALLBACK
   */
  gtk_signal_connect (GTK_OBJECT (check_tips), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_TIPS);
  
  return (GtkWidget *) general_frame;
}



GtkWidget *rubrica_preferences_add_view_page(GConfClient *client)
{
  GtkWidget *view_frame;

  GtkWidget *card_check;
  GtkWidget *first_name_check;
  GtkWidget *last_name_check;
  GtkWidget *prof_check;
  GtkWidget *city_check;
  GtkWidget *country_check;
  GtkWidget *web_check;
  GtkWidget *email_check;
  GtkWidget *tel_check;
  GtkWidget *company_check;
  GtkWidget *assigment_check;

  GtkWidget *middle_name_check;
  GtkWidget *name_pref_check;
  GtkWidget *title_check;
  GtkWidget *birth_check;
  GtkWidget *street_check;
  GtkWidget *street_num_check;
  GtkWidget *zip_check;
  GtkWidget *province_check;
  GtkWidget *state_check;

  GtkWidget *show_company_check;
  GtkWidget *street_job_check;
  GtkWidget *street_numb_job_check;
  GtkWidget *zip_job_check;
  GtkWidget *city_job_check;
  GtkWidget *province_job_check;
  GtkWidget *country_job_check;
  GtkWidget *web_job_check;
  GtkWidget *email_job_check;
  GtkWidget *operator_check;
  GtkWidget *fax_check;
  GtkWidget *green_check;
  GtkWidget *customer_care_check;
  GtkWidget *note_job_check;
  GtkWidget *assigment_job_check;
  GtkWidget *org_check;
  GtkWidget *dep_check;
  GtkWidget *sub_dep_check;
  GtkWidget *secretary_check;
  GtkWidget *secretary_tel_check;

  GtkWidget *married_check;
  GtkWidget *spouse_check;
  GtkWidget *children_check;
  GtkWidget *spouse_birth_check;
  GtkWidget *child_note_check;
  GtkWidget *note_check;

  GSList *data_show_pers_group = NULL;
  GSList *data_show_work_group = NULL;
  GSList *data_show_note_group = NULL;
  GtkWidget *view_some_pers_radio;
  GtkWidget *view_all_pers_radio;
  GtkWidget *view_some_job_radio;
  GtkWidget *view_all_job_radio;
  GtkWidget *view_some_note_radio;
  GtkWidget *view_all_note_radio;

  GtkWidget *view_card_frame;
  GtkWidget *view_data_frame;

  GtkWidget *view_job_data_table;
  GtkWidget *view_card_table;
  GtkWidget *view_pers_data_table;
  GtkWidget *view_note_data_table;

  GtkWidget *view_box;
  GtkWidget *view_card_box;
  GtkWidget *view_data_box;
  GtkWidget *view_pers_data_box;
  GtkWidget *view_job_data_box;
  GtkWidget *view_note_data_box;

  GtkWidget *view_card_label;
  GtkWidget *view_data_label;
  GtkWidget *view_data_pers_label;
  GtkWidget *view_data_job_label;
  GtkWidget *view_data_note_label;

  GtkWidget *hseparator1;
  GtkWidget *hseparator2;


  view_frame = gtk_frame_new (_(" Rubrica's view "));
  gtk_widget_show (view_frame);
  gtk_container_set_border_width (GTK_CONTAINER (view_frame), 2);

  view_box = gtk_vbox_new (FALSE, 5);
  gtk_widget_show (view_box);
  gtk_container_add (GTK_CONTAINER (view_frame), view_box);
  gtk_container_set_border_width (GTK_CONTAINER (view_box), 3);

  view_card_frame = gtk_frame_new (_(" Card's window"));
  gtk_widget_show (view_card_frame);
  gtk_box_pack_start (GTK_BOX (view_box), view_card_frame, FALSE, FALSE, 0);

  view_card_box = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (view_card_box);
  gtk_container_add (GTK_CONTAINER (view_card_frame), view_card_box);

  view_card_label = gtk_label_new (_("Displayed colums in card's window:"));
  gtk_widget_show (view_card_label);
  gtk_box_pack_start (GTK_BOX (view_card_box), view_card_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (view_card_label), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (view_card_label), 5, 0);

  view_card_table = gtk_table_new (3, 5, FALSE);
  gtk_widget_show (view_card_table);
  gtk_box_pack_start (GTK_BOX (view_card_box), view_card_table, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (view_card_table), 2);

  card_check = gtk_check_button_new_with_label (_("Card"));
  gtk_widget_set_name (card_check, RUBRICA_KEY_SHOW_COLUMN_CARD);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_COLUMN_CARD, 
		       card_check);
  gtk_widget_show (card_check);
  gtk_table_attach (GTK_TABLE (view_card_table), card_check, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(card_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_CARD);
  /*    ---------------------------------------------------------------------  */

  first_name_check = gtk_check_button_new_with_label (_("First Name"));
  gtk_widget_set_name (first_name_check, RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME, first_name_check);
  gtk_widget_show (first_name_check);
  gtk_table_attach (GTK_TABLE (view_card_table), first_name_check, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(first_name_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME);
  /*    ---------------------------------------------------------------------  */

  last_name_check = gtk_check_button_new_with_label (_("Last Name"));
  gtk_widget_set_name (last_name_check, RUBRICA_KEY_SHOW_COLUMN_LAST_NAME);
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), 
		      RUBRICA_KEY_SHOW_COLUMN_LAST_NAME, last_name_check);
  gtk_widget_show (last_name_check);
  gtk_table_attach (GTK_TABLE (view_card_table), last_name_check, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(last_name_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_LAST_NAME);
  /*    ---------------------------------------------------------------------  */

  prof_check = gtk_check_button_new_with_label (_("Profession"));
  gtk_widget_set_name (prof_check, RUBRICA_KEY_SHOW_COLUMN_PROFESSION);
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), 
		      RUBRICA_KEY_SHOW_COLUMN_PROFESSION, prof_check);
  gtk_widget_show (prof_check);
  gtk_table_attach (GTK_TABLE (view_card_table), prof_check, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(prof_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_PROFESSION);
  /*    ---------------------------------------------------------------------  */

  city_check = gtk_check_button_new_with_label (_("City"));
  gtk_widget_set_name (city_check, RUBRICA_KEY_SHOW_COLUMN_CITY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_COLUMN_CITY,
		       city_check);
  gtk_widget_show (city_check);
  gtk_table_attach (GTK_TABLE (view_card_table), city_check, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(city_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_CITY);
  /*    ---------------------------------------------------------------------  */

  country_check = gtk_check_button_new_with_label (_("Country"));
  gtk_widget_set_name (country_check, RUBRICA_KEY_SHOW_COLUMN_COUNTRY);
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_COLUMN_COUNTRY,
		      country_check);
  gtk_widget_show (country_check);
  gtk_table_attach (GTK_TABLE (view_card_table), country_check, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(country_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_COUNTRY);
  /*    ---------------------------------------------------------------------  */

  web_check = gtk_check_button_new_with_label (_("Web "));
  gtk_widget_set_name (web_check, RUBRICA_KEY_SHOW_COLUMN_WEB);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_COLUMN_WEB, 
		       web_check);
  gtk_widget_show (web_check);
  gtk_table_attach (GTK_TABLE (view_card_table), web_check, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(web_check, client, RUBRICA_KEY_SHOW_COLUMN_WEB);
  /*    ---------------------------------------------------------------------  */

  email_check = gtk_check_button_new_with_label (_("Email"));
  gtk_widget_set_name (email_check, RUBRICA_KEY_SHOW_COLUMN_EMAIL);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_COLUMN_EMAIL, 
		       email_check);
  gtk_widget_show (email_check);
  gtk_table_attach (GTK_TABLE (view_card_table), email_check, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(email_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_EMAIL);
  /*    ---------------------------------------------------------------------  */

  tel_check = gtk_check_button_new_with_label (_("Telephone"));
  gtk_widget_set_name (tel_check, RUBRICA_KEY_SHOW_COLUMN_TELEPHONE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_COLUMN_TELEPHONE, tel_check);
  gtk_widget_show (tel_check);
  gtk_table_attach (GTK_TABLE (view_card_table), tel_check, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(tel_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_TELEPHONE);
  /*    ---------------------------------------------------------------------  */

  company_check = gtk_check_button_new_with_label (_("Company"));
  gtk_widget_set_name (company_check, RUBRICA_KEY_SHOW_COLUMN_COMPANY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_COLUMN_COMPANY,
		       company_check);
  gtk_widget_show (company_check);
  gtk_table_attach (GTK_TABLE (view_card_table), company_check, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(company_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_COMPANY);
  /*    ---------------------------------------------------------------------  */

  assigment_check = gtk_check_button_new_with_label (_("Assigment"));
  gtk_widget_set_name (assigment_check, RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT, 
		       assigment_check);
  gtk_widget_show (assigment_check);
  gtk_table_attach (GTK_TABLE (view_card_table), assigment_check, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(assigment_check, client, 
				      RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT);
  /*    ---------------------------------------------------------------------  */


  /* Frame data 
   */
  view_data_frame = gtk_frame_new (_(" Data's window "));
  gtk_widget_show (view_data_frame);
  gtk_box_pack_start (GTK_BOX (view_box), view_data_frame, FALSE, FALSE, 0);

  view_data_box = gtk_vbox_new (FALSE, 0);

  /*    SENSITIVE FALSE
   */    
  gtk_widget_set_sensitive(view_data_box, FALSE);

  gtk_widget_show (view_data_box);
  gtk_container_add (GTK_CONTAINER (view_data_frame), view_data_box);
  gtk_container_set_border_width (GTK_CONTAINER (view_data_box), 1);

  view_data_label = gtk_label_new (_("Check the items you want see in data window:"));
  gtk_widget_show (view_data_label);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_data_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (view_data_label), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (view_data_label), 5, 0);

  view_pers_data_box = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (view_pers_data_box);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_pers_data_box, FALSE, FALSE, 0);

  view_data_pers_label = gtk_label_new (_("Personal data: "));
  gtk_widget_show (view_data_pers_label);
  gtk_box_pack_start (GTK_BOX (view_pers_data_box), view_data_pers_label,
		      FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (view_data_pers_label), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (view_data_pers_label), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (view_data_pers_label), 5, 0);

  /* radio button -- show only checked
   */
  view_some_pers_radio = gtk_radio_button_new_with_label (data_show_pers_group, 
							  _("Show only checked items"));
  data_show_pers_group = gtk_radio_button_group (GTK_RADIO_BUTTON 
						 (view_some_pers_radio));
  gtk_widget_set_name (view_some_pers_radio, RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME, view_some_pers_radio);
  gtk_widget_show (view_some_pers_radio);
  gtk_box_pack_start (GTK_BOX (view_pers_data_box), view_some_pers_radio, 
		      FALSE, FALSE, 0);

  /* radio button -- show all
   */
  view_all_pers_radio = gtk_radio_button_new_with_label (data_show_pers_group, 
							 _("Show all personal items "));
  data_show_pers_group = gtk_radio_button_group(GTK_RADIO_BUTTON (view_all_pers_radio));
  gtk_widget_set_name (view_all_pers_radio, RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),
		       RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL, view_all_pers_radio);
  gtk_widget_show (view_all_pers_radio);
  gtk_box_pack_start (GTK_BOX (view_pers_data_box), view_all_pers_radio,
		      FALSE, FALSE, 0);

  /*    ---------------------------------------------------------------------
	GConf settings for radio buttons.
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(view_some_pers_radio, view_all_pers_radio, 
				      client, 
				      RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME,
				      RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL);
  /*    ---------------------------------------------------------------------  */

  /* check table
   */
  view_pers_data_table = gtk_table_new (2, 5, FALSE);
  gtk_widget_set_name (view_pers_data_table, "data_table");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),
		       "data_table", view_pers_data_table);
  gtk_widget_show (view_pers_data_table);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_pers_data_table, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (view_pers_data_table), 2);

  middle_name_check = gtk_check_button_new_with_label (_("Middle name"));
  gtk_widget_set_name (middle_name_check, RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME, middle_name_check);
  gtk_widget_show (middle_name_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), middle_name_check, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(middle_name_check, client, 
				      RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME);
  /*    ---------------------------------------------------------------------  */

  name_pref_check = gtk_check_button_new_with_label (_("Name prefix"));
  gtk_widget_set_name (name_pref_check, RUBRICA_KEY_SHOW_DATA_NAME_PREFIX);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_NAME_PREFIX, name_pref_check);
  gtk_widget_show (name_pref_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), name_pref_check, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(name_pref_check, client, 
				      RUBRICA_KEY_SHOW_DATA_NAME_PREFIX);
  /*    ---------------------------------------------------------------------  */
  title_check = gtk_check_button_new_with_label (_("Title"));
  gtk_widget_set_name (title_check, RUBRICA_KEY_SHOW_DATA_TITLE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_TITLE,
		       title_check);
  gtk_widget_show (title_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), title_check, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(title_check, client, 
				      RUBRICA_KEY_SHOW_DATA_TITLE);
   /*    ---------------------------------------------------------------------  */

  birth_check = gtk_check_button_new_with_label (_("Birthday"));
  gtk_widget_set_name (birth_check, RUBRICA_KEY_SHOW_DATA_BIRTHDAY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_BIRTHDAY,
		       birth_check);
  gtk_widget_show (birth_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), birth_check, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(birth_check, client, 
				      RUBRICA_KEY_SHOW_DATA_BIRTHDAY);
  /*    ---------------------------------------------------------------------  */

  street_check = gtk_check_button_new_with_label (_("Street"));
  gtk_widget_set_name (street_check, RUBRICA_KEY_SHOW_DATA_STREET);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_STREET,
		       street_check);
  gtk_widget_show (street_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), street_check, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(street_check, client, 
				      RUBRICA_KEY_SHOW_DATA_STREET);
  /*    ---------------------------------------------------------------------  */

  street_num_check = gtk_check_button_new_with_label (_("Street number"));
  gtk_widget_set_name (street_num_check, RUBRICA_KEY_SHOW_DATA_STREET_NUM);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_STREET_NUM, street_num_check);
  gtk_widget_show (street_num_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), street_num_check, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(street_num_check, client, 
				      RUBRICA_KEY_SHOW_DATA_STREET_NUM);
  /*    ---------------------------------------------------------------------  */

  zip_check = gtk_check_button_new_with_label (_("Zip code"));
  gtk_widget_set_name (zip_check, RUBRICA_KEY_SHOW_DATA_ZIP_CODE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_ZIP_CODE,
		       zip_check);
  gtk_widget_show (zip_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), zip_check, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(zip_check, client, 
				      RUBRICA_KEY_SHOW_DATA_ZIP_CODE);
  /*    ---------------------------------------------------------------------  */

  province_check = gtk_check_button_new_with_label (_("Province"));
  gtk_widget_set_name (province_check, RUBRICA_KEY_SHOW_DATA_PROVINCE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_PROVINCE,
		       province_check);
  gtk_widget_show (province_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), province_check, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(province_check, client, 
				      RUBRICA_KEY_SHOW_DATA_PROVINCE);

  /*    ---------------------------------------------------------------------  */

  state_check = gtk_check_button_new_with_label (_("State"));
  gtk_widget_set_name (state_check, RUBRICA_KEY_SHOW_DATA_STATE );
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_STATE, 
		       state_check);
  gtk_widget_show (state_check);
  gtk_table_attach (GTK_TABLE (view_pers_data_table), state_check, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(state_check, client, 
				      RUBRICA_KEY_SHOW_DATA_STATE);
  /*    ---------------------------------------------------------------------  */

  hseparator1 = gtk_hseparator_new ();
  gtk_widget_show (hseparator1);
  gtk_box_pack_start (GTK_BOX (view_data_box), hseparator1, FALSE, FALSE, 0);

  view_job_data_box = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (view_job_data_box);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_job_data_box, FALSE, FALSE, 0);

  view_data_job_label = gtk_label_new (_("Company and work data:  "));
  gtk_widget_show (view_data_job_label);
  gtk_box_pack_start (GTK_BOX (view_job_data_box), view_data_job_label, 
		      FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (view_data_job_label), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (view_data_job_label), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (view_data_job_label), 5, 0);

  view_some_job_radio = gtk_radio_button_new_with_label (data_show_work_group, 
							 _("Show only checked items"));
  data_show_work_group = gtk_radio_button_group(GTK_RADIO_BUTTON (view_some_job_radio));
  gtk_widget_set_name (view_some_job_radio, RUBRICA_KEY_SHOW_DATA_JOB_SOME);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_JOB_SOME, 
		       view_some_job_radio);
  gtk_widget_show (view_some_job_radio);
  gtk_box_pack_start (GTK_BOX (view_job_data_box), view_some_job_radio,
		      FALSE, FALSE, 0);

  view_all_job_radio = gtk_radio_button_new_with_label (data_show_work_group, 
							_("Show all items "));
  data_show_work_group = gtk_radio_button_group (GTK_RADIO_BUTTON (view_all_job_radio));
  gtk_widget_set_name (view_all_job_radio, RUBRICA_KEY_SHOW_DATA_JOB_ALL);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_JOB_ALL, 
		       view_all_job_radio);
  gtk_widget_show (view_all_job_radio);
  gtk_box_pack_start (GTK_BOX (view_job_data_box), view_all_job_radio, FALSE, FALSE, 0);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(view_some_job_radio, view_all_job_radio, 
				      client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_SOME,
				      RUBRICA_KEY_SHOW_DATA_JOB_ALL);
  /*    ---------------------------------------------------------------------  */

  view_job_data_table = gtk_table_new (4, 5, FALSE);
  gtk_widget_set_name (view_job_data_table, "job_table");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),
		       "job_table", view_job_data_table);
  gtk_widget_show (view_job_data_table);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_job_data_table, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (view_job_data_table), 2);

  show_company_check = gtk_check_button_new_with_label (_("Company"));
  gtk_widget_set_name (show_company_check, RUBRICA_KEY_SHOW_DATA_COMPANY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_COMPANY,
		       show_company_check);
  gtk_widget_show (show_company_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), show_company_check, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(show_company_check, client, 
				      RUBRICA_KEY_SHOW_DATA_COMPANY);
  /*    ---------------------------------------------------------------------  */

  street_job_check = gtk_check_button_new_with_label (_("Street"));
  gtk_widget_set_name (street_job_check, RUBRICA_KEY_SHOW_DATA_JOB_STREET);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),
		       RUBRICA_KEY_SHOW_DATA_JOB_STREET, street_job_check);
  gtk_widget_show (street_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), street_job_check, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(street_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_STREET);
 /*    ---------------------------------------------------------------------  */

  street_numb_job_check = gtk_check_button_new_with_label (_("Street number"));
  gtk_widget_set_name (street_numb_job_check, RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM, street_numb_job_check);
  gtk_widget_show (street_numb_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), street_numb_job_check, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(street_numb_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM);
  /*    ---------------------------------------------------------------------  */

  zip_job_check = gtk_check_button_new_with_label (_("Zip code"));
  gtk_widget_set_name (zip_job_check, RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE, zip_job_check);
  gtk_widget_show (zip_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), zip_job_check, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(zip_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE);
  /*    ---------------------------------------------------------------------  */
  city_job_check = gtk_check_button_new_with_label (_("City"));
  gtk_widget_set_name (city_job_check, RUBRICA_KEY_SHOW_DATA_JOB_CITY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_JOB_CITY, 
		       city_job_check);
  gtk_widget_show (city_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), city_job_check, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(city_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_CITY);
  /*    ---------------------------------------------------------------------  */

  province_job_check = gtk_check_button_new_with_label (_("Province"));
  gtk_widget_set_name (province_job_check, RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE, province_job_check);
  gtk_widget_show (province_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), province_job_check, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(province_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE);
  /*    ---------------------------------------------------------------------  */

  country_job_check = gtk_check_button_new_with_label (_("Country"));
  gtk_widget_set_name (country_job_check, RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY,country_job_check);
  gtk_widget_show (country_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), country_job_check, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(country_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY);
 /*    ---------------------------------------------------------------------  */

  web_job_check = gtk_check_button_new_with_label (_("Web"));
  gtk_widget_set_name (web_job_check, RUBRICA_KEY_SHOW_DATA_JOB_WEB);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_JOB_WEB,
		       web_job_check);
  gtk_widget_show (web_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), web_job_check, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(web_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_WEB);
 /*    ---------------------------------------------------------------------  */

  email_job_check = gtk_check_button_new_with_label (_("Email"));
  gtk_widget_set_name (email_job_check, RUBRICA_KEY_SHOW_DATA_JOB_EMAIL);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_JOB_EMAIL, email_job_check);
  gtk_widget_show (email_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), email_job_check, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(email_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_EMAIL);
  /*    ---------------------------------------------------------------------  */

  operator_check = gtk_check_button_new_with_label (_("Operator"));
  gtk_widget_set_name (operator_check, RUBRICA_KEY_SHOW_DATA_OPERATOR);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_OPERATOR, 
		       operator_check);
  gtk_widget_show (operator_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), operator_check, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(operator_check, client, 
				      RUBRICA_KEY_SHOW_DATA_OPERATOR);
  /*    ---------------------------------------------------------------------  */

  fax_check = gtk_check_button_new_with_label (_("Fax"));
  gtk_widget_set_name (fax_check, RUBRICA_KEY_SHOW_DATA_FAX);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_FAX, 
		       fax_check);
  gtk_widget_show (fax_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), fax_check, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(fax_check, client, 
				      RUBRICA_KEY_SHOW_DATA_FAX);
 /*    ---------------------------------------------------------------------  */

  green_check = gtk_check_button_new_with_label (_("Green"));
  gtk_widget_set_name (green_check, RUBRICA_KEY_SHOW_DATA_GREEN);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_GREEN, 
		       green_check);
  gtk_widget_show (green_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), green_check, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(green_check, client, 
				      RUBRICA_KEY_SHOW_DATA_GREEN);
  /*    ---------------------------------------------------------------------  */

  customer_care_check = gtk_check_button_new_with_label (_("Customer care"));
  gtk_widget_set_name (customer_care_check, RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE, customer_care_check);
  gtk_widget_show (customer_care_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), customer_care_check, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(customer_care_check, client, 
				      RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE);
  /*    ---------------------------------------------------------------------  */

  note_job_check = gtk_check_button_new_with_label (_("Notes"));
  gtk_widget_set_name (note_job_check, RUBRICA_KEY_SHOW_DATA_JOB_NOTE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_JOB_NOTE, 
		       note_job_check);
  gtk_widget_show (note_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), note_job_check, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(note_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_JOB_NOTE);
  /*    ---------------------------------------------------------------------  */

  assigment_job_check = gtk_check_button_new_with_label (_("Assigment"));
  gtk_widget_set_name (assigment_job_check, RUBRICA_KEY_SHOW_DATA_ASSIGMENT);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),
		       RUBRICA_KEY_SHOW_DATA_ASSIGMENT, assigment_job_check);
  gtk_widget_show (assigment_job_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), assigment_job_check, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(assigment_job_check, client, 
				      RUBRICA_KEY_SHOW_DATA_ASSIGMENT);
  /*    ---------------------------------------------------------------------  */

  org_check = gtk_check_button_new_with_label (_("Organization"));
  gtk_widget_set_name (org_check, RUBRICA_KEY_SHOW_DATA_ORG);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_ORG, 
		       org_check);
  gtk_widget_show (org_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), org_check, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(org_check, client, 
				      RUBRICA_KEY_SHOW_DATA_ORG);
  /*    ---------------------------------------------------------------------  */

  dep_check = gtk_check_button_new_with_label (_("Department"));
  gtk_widget_set_name (dep_check, RUBRICA_KEY_SHOW_DATA_DEP);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_DEP, 
		       dep_check);
  gtk_widget_show (dep_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), dep_check, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(dep_check, client, 
				      RUBRICA_KEY_SHOW_DATA_DEP);
  /*    ---------------------------------------------------------------------  */

  sub_dep_check = gtk_check_button_new_with_label (_("Sub department"));
  gtk_widget_set_name (sub_dep_check, RUBRICA_KEY_SHOW_DATA_SUB_DEP);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_SUB_DEP, 
		       sub_dep_check);
  gtk_widget_show (sub_dep_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), sub_dep_check, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(sub_dep_check, client, 
				      RUBRICA_KEY_SHOW_DATA_SUB_DEP);
  /*    ---------------------------------------------------------------------  */

  secretary_check = gtk_check_button_new_with_label (_("Secretary name"));
  gtk_widget_set_name (secretary_check, RUBRICA_KEY_SHOW_DATA_SECRETARY);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_SECRETARY,
		       secretary_check);
  gtk_widget_show (secretary_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), secretary_check, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(secretary_check, client, 
				      RUBRICA_KEY_SHOW_DATA_SECRETARY);
  /*    ---------------------------------------------------------------------  */

  secretary_tel_check = gtk_check_button_new_with_label (_("Secretary phone"));
  gtk_widget_set_name (secretary_tel_check, RUBRICA_KEY_SHOW_DATA_SECR_PHONE);
  gtk_object_set_data (GTK_OBJECT(preferences_dialog), RUBRICA_KEY_SHOW_DATA_SECR_PHONE,
		       secretary_tel_check);
  gtk_widget_show (secretary_tel_check);
  gtk_table_attach (GTK_TABLE (view_job_data_table), secretary_tel_check, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(secretary_tel_check, client, 
				      RUBRICA_KEY_SHOW_DATA_SECR_PHONE);
  /*    ---------------------------------------------------------------------  */

  hseparator2 = gtk_hseparator_new ();
  gtk_widget_show (hseparator2);
  gtk_box_pack_start (GTK_BOX (view_data_box), hseparator2, TRUE, TRUE, 0);

  view_note_data_box = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (view_note_data_box);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_note_data_box, FALSE, FALSE, 0);

  view_data_note_label = gtk_label_new (_("Personal Notes: "));
  gtk_widget_show (view_data_note_label);
  gtk_box_pack_start (GTK_BOX (view_note_data_box), view_data_note_label, 
		      FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (view_data_note_label), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (view_data_note_label), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (view_data_note_label), 5, 0);

  view_some_note_radio = gtk_radio_button_new_with_label (data_show_note_group, 
							  _("Show only checked items"));
  data_show_note_group = gtk_radio_button_group(GTK_RADIO_BUTTON(view_some_note_radio));
  gtk_widget_set_name (view_some_note_radio, RUBRICA_KEY_SHOW_DATA_NOTES_SOME);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),RUBRICA_KEY_SHOW_DATA_NOTES_SOME,
		       view_some_note_radio);
  gtk_widget_show (view_some_note_radio);
  gtk_box_pack_start (GTK_BOX (view_note_data_box), view_some_note_radio,
		      FALSE, FALSE, 0);

  view_all_note_radio = gtk_radio_button_new_with_label (data_show_note_group, 
							 _("Show all items "));
  data_show_note_group = gtk_radio_button_group (GTK_RADIO_BUTTON(view_all_note_radio));
  gtk_widget_set_name (view_all_note_radio, RUBRICA_KEY_SHOW_DATA_NOTES_ALL);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_NOTES_ALL,
		       view_all_note_radio);
  gtk_widget_show (view_all_note_radio);
  gtk_box_pack_start (GTK_BOX (view_note_data_box), view_all_note_radio,
		      FALSE, FALSE, 0);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(view_some_note_radio, view_all_note_radio, 
				      client, 
				      RUBRICA_KEY_SHOW_DATA_NOTES_SOME,
				      RUBRICA_KEY_SHOW_DATA_NOTES_ALL);
  /*    ---------------------------------------------------------------------  */

  view_note_data_table = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (view_note_data_table, "note_table");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog),
		       "note_table", view_note_data_table);
  gtk_widget_show (view_note_data_table);
  gtk_box_pack_start (GTK_BOX (view_data_box), view_note_data_table, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (view_note_data_table), 2);

  married_check = gtk_check_button_new_with_label (_("Married"));
  gtk_widget_set_name (married_check, RUBRICA_KEY_SHOW_DATA_MARRIED);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_MARRIED, 
		       married_check);
  gtk_widget_show (married_check);
  gtk_table_attach (GTK_TABLE (view_note_data_table), married_check, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(married_check, client, 
				      RUBRICA_KEY_SHOW_DATA_MARRIED);
  /*    ---------------------------------------------------------------------  */

  spouse_check = gtk_check_button_new_with_label (_("Spouse name"));
  gtk_widget_set_name (spouse_check, RUBRICA_KEY_SHOW_DATA_SPOUSE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_SPOUSE, 
		       spouse_check);
  gtk_widget_show (spouse_check);
  gtk_table_attach (GTK_TABLE (view_note_data_table), spouse_check, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(spouse_check, client, 
				      RUBRICA_KEY_SHOW_DATA_SPOUSE);
 /*    ---------------------------------------------------------------------  */

  children_check = gtk_check_button_new_with_label (_("Children"));
  gtk_widget_set_name (children_check, RUBRICA_KEY_SHOW_DATA_CHILDREN);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_CHILDREN, 
		       children_check);
  gtk_widget_show (children_check);
  gtk_table_attach (GTK_TABLE (view_note_data_table), children_check, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(children_check, client, 
				      RUBRICA_KEY_SHOW_DATA_CHILDREN);
  /*    ---------------------------------------------------------------------  */

  spouse_birth_check = gtk_check_button_new_with_label (_("Spouse birthday"));
  gtk_widget_set_name (spouse_birth_check, RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH, spouse_birth_check);
  gtk_widget_show (spouse_birth_check);
  gtk_table_attach (GTK_TABLE (view_note_data_table), spouse_birth_check, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(spouse_birth_check, client, 
				      RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH);
  /*    ---------------------------------------------------------------------  */

  child_note_check = gtk_check_button_new_with_label (_("Children notes"));
  gtk_widget_set_name (child_note_check, RUBRICA_KEY_SHOW_DATA_CHILD_NOTE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), 
		       RUBRICA_KEY_SHOW_DATA_CHILD_NOTE, child_note_check);
  gtk_widget_show (child_note_check);
  gtk_table_attach (GTK_TABLE (view_note_data_table), child_note_check, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(child_note_check, client, 
				      RUBRICA_KEY_SHOW_DATA_CHILD_NOTE);
  /*    ---------------------------------------------------------------------  */

  note_check = gtk_check_button_new_with_label (_("Notes"));
  gtk_widget_set_name (note_check, RUBRICA_KEY_SHOW_DATA_NOTE);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW_DATA_NOTE, 
		       note_check);
  gtk_widget_show (note_check);
  gtk_table_attach (GTK_TABLE (view_note_data_table), note_check, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
 /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(note_check, client, 
				      RUBRICA_KEY_SHOW_DATA_NOTE);
 /*    ---------------------------------------------------------------------  */


  gtk_signal_connect (GTK_OBJECT (card_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_CARD);

  gtk_signal_connect (GTK_OBJECT (first_name_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_FIRST_NAME);

  gtk_signal_connect (GTK_OBJECT (last_name_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_LAST_NAME);

  gtk_signal_connect (GTK_OBJECT (prof_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_PROFESSION);

  gtk_signal_connect (GTK_OBJECT (city_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_CITY);

  gtk_signal_connect (GTK_OBJECT (country_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_COUNTRY);

  gtk_signal_connect (GTK_OBJECT (web_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_WEB);

  gtk_signal_connect (GTK_OBJECT (email_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_EMAIL);

  gtk_signal_connect (GTK_OBJECT (tel_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_TELEPHONE);

  gtk_signal_connect (GTK_OBJECT (company_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_COMPANY);

  gtk_signal_connect (GTK_OBJECT (assigment_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_column_check_toggled),
                      RUBRICA_KEY_SHOW_COLUMN_ASSIGMENT);



  gtk_signal_connect (GTK_OBJECT (middle_name_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_MIDDLE_NAME);

  gtk_signal_connect (GTK_OBJECT (name_pref_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_NAME_PREFIX);

  gtk_signal_connect (GTK_OBJECT (title_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_TITLE);

  gtk_signal_connect (GTK_OBJECT (birth_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_BIRTHDAY);

  gtk_signal_connect (GTK_OBJECT (street_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
		      RUBRICA_KEY_SHOW_DATA_STREET);

  gtk_signal_connect (GTK_OBJECT (street_num_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_STREET_NUM);

  gtk_signal_connect (GTK_OBJECT (zip_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_ZIP_CODE);

  gtk_signal_connect (GTK_OBJECT (province_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_PROVINCE);

  gtk_signal_connect (GTK_OBJECT (state_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_STATE);

  gtk_signal_connect (GTK_OBJECT (show_company_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_COMPANY);

  gtk_signal_connect (GTK_OBJECT (street_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_STREET);

  gtk_signal_connect (GTK_OBJECT (street_numb_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_STREET_NUM);

  gtk_signal_connect (GTK_OBJECT (zip_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_ZIP_CODE);

  gtk_signal_connect (GTK_OBJECT (city_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_CITY);

  gtk_signal_connect (GTK_OBJECT (province_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_PROVINCE);

  gtk_signal_connect (GTK_OBJECT (country_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_COUNTRY);

  gtk_signal_connect (GTK_OBJECT (web_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_WEB);

  gtk_signal_connect (GTK_OBJECT (email_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_EMAIL);

  gtk_signal_connect (GTK_OBJECT (operator_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_OPERATOR);

  gtk_signal_connect (GTK_OBJECT (fax_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_FAX);

  gtk_signal_connect (GTK_OBJECT (green_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_GREEN);

  gtk_signal_connect (GTK_OBJECT (customer_care_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_CUSTOMER_CARE);

  gtk_signal_connect (GTK_OBJECT (note_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_NOTE);

  gtk_signal_connect (GTK_OBJECT (assigment_job_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_ASSIGMENT);

  gtk_signal_connect (GTK_OBJECT (org_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_ORG);

  gtk_signal_connect (GTK_OBJECT (dep_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_DEP);

  gtk_signal_connect (GTK_OBJECT (sub_dep_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_SUB_DEP);

  gtk_signal_connect (GTK_OBJECT (secretary_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_SECRETARY);

  gtk_signal_connect (GTK_OBJECT (secretary_tel_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_SECR_PHONE);

  gtk_signal_connect (GTK_OBJECT (married_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_MARRIED);

  gtk_signal_connect (GTK_OBJECT (spouse_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_SPOUSE);

  gtk_signal_connect (GTK_OBJECT (children_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_CHILDREN);

  gtk_signal_connect (GTK_OBJECT (spouse_birth_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_SPOUSE_BIRTH);

  gtk_signal_connect (GTK_OBJECT (child_note_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_CHILD_NOTE);

  gtk_signal_connect (GTK_OBJECT (note_check), "toggled",
                      GTK_SIGNAL_FUNC (on_show_data_check_toggled),
                      RUBRICA_KEY_SHOW_DATA_NOTE);


  gtk_signal_connect (GTK_OBJECT (view_some_pers_radio), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
                      RUBRICA_KEY_SHOW_DATA_PERSONAL_SOME);
  gtk_signal_connect (GTK_OBJECT (view_all_pers_radio), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
		      RUBRICA_KEY_SHOW_DATA_PERSONAL_ALL);

  gtk_signal_connect (GTK_OBJECT (view_some_job_radio), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_SOME);
  gtk_signal_connect (GTK_OBJECT (view_all_job_radio), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
                      RUBRICA_KEY_SHOW_DATA_JOB_ALL);

  gtk_signal_connect (GTK_OBJECT (view_some_note_radio), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
                      RUBRICA_KEY_SHOW_DATA_NOTES_SOME);
  gtk_signal_connect (GTK_OBJECT (view_all_note_radio), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
                      RUBRICA_KEY_SHOW_DATA_NOTES_ALL);

  return view_frame;
}


GtkWidget *rubrica_preferences_add_translation_page(GConfClient *client)
{
  GtkWidget *translation_frame;

  GtkWidget *box_translation;
  GtkWidget *box_rules;
  GtkWidget *box_dict;
  GtkWidget *box_default_dict;
  GtkWidget *box_user_language;
  GtkWidget *box_io;
  GtkWidget *buttonbox_io;

  GtkWidget *load;
  GtkWidget *save;
  GtkWidget *show_rules;

  GSList *opt_other_lang_group = NULL;
  GSList *opt_def_lang_group = NULL;

  GtkWidget *radio_external_dict;
  GtkWidget *radio_default_dict;
  GtkWidget *radio_italian;
  GtkWidget *radio_english;  

  GtkWidget *notebook_dict;

  /*    entry
  */
  GtkWidget *entry_user_language;

  GtkWidget *entry_first_name;
  GtkWidget *entry_middle_name;
  GtkWidget *entry_last_name;
  GtkWidget *entry_profession;
  GtkWidget *entry_name_prefix;
  GtkWidget *entry_title;
  GtkWidget *entry_card;
  GtkWidget *entry_data;

  GtkWidget *entry_address;
  GtkWidget *entry_street;
  GtkWidget *entry_street_number;
  GtkWidget *entry_zip_code;
  GtkWidget *entry_city;
  GtkWidget *entry_province;
  GtkWidget *entry_country;
  GtkWidget *entry_state;

  GtkWidget *entry_web_address;
  GtkWidget *entry_web;
  GtkWidget *entry_email_address;
  GtkWidget *entry_email;

  GtkWidget *entry_tel_list;
  GtkWidget *entry_telephone;
  GtkWidget *entry_type;

  GtkWidget *entry_company_name;
  GtkWidget *entry_operator;
  GtkWidget *entry_green;
  GtkWidget *entry_company;
  GtkWidget *entry_customer_care;
  GtkWidget *entry_fax;

  GtkWidget *entry_assigment;
  GtkWidget *entry_organization;
  GtkWidget *entry_sub_dep;
  GtkWidget *entry_secretary_phone;
  GtkWidget *entry_department;
  GtkWidget *entry_secretary;
  GtkWidget *entry_work;

  GtkWidget *entry_anniversary;
  GtkWidget *entry_spouse_name;
  GtkWidget *entry_married;
  GtkWidget *entry_children;
  GtkWidget *entry_hobby;
  GtkWidget *entry_public_key;
  GtkWidget *entry_notes;
  GtkWidget *entry_child_notes;

  GtkWidget *entry_modify;
  GtkWidget *entry_delete;
  GtkWidget *entry_created;
  GtkWidget *entry_last_change;
  GtkWidget *entry_name;
  GtkWidget *entry_birthday;
  GtkWidget *entry_other_notes;

  /* ------------------------
   */
  GtkWidget *rules_frame;
  GtkWidget *io_frame;
  GtkWidget *dictionary_frame;
  GtkWidget *frame_personal_data;
  GtkWidget *frame_address;
  GtkWidget *frame_net;
  GtkWidget *frame_telephone;
  GtkWidget *frame_company;
  GtkWidget *frame_work;
  GtkWidget *frame_notes;
  GtkWidget *frame_misc;

  GtkWidget *table_personal_data;
  GtkWidget *table_address;
  GtkWidget *table_net;
  GtkWidget *table_telephone;
  GtkWidget *table_compamy;
  GtkWidget *table_work;
  GtkWidget *table_notes;
  GtkWidget *table_misc;

  GtkWidget *personal_tab;
  GtkWidget *address_tab;
  GtkWidget *net_tab;
  GtkWidget *telephone_tab;
  GtkWidget *company_tab;
  GtkWidget *work_tab;
  GtkWidget *notes_tab;
  GtkWidget *misc_tab;

  GtkWidget *label_dictionary;
  GtkWidget *label_default_dict;
  GtkWidget *label_user_language;

  GtkWidget *label_card;
  GtkWidget *label_data;
  GtkWidget *label_first_name;
  GtkWidget *label_middle_name;
  GtkWidget *label_last_name;
  GtkWidget *label_profession;
  GtkWidget *label_name_prefix;
  GtkWidget *label_title;

  GtkWidget *label_address;
  GtkWidget *label_street;
  GtkWidget *label_street_num;
  GtkWidget *label_zip_code;
  GtkWidget *label_city;
  GtkWidget *label_province;
  GtkWidget *label_country;
  GtkWidget *label_state;

  GtkWidget *label_web_address;
  GtkWidget *label_web;
  GtkWidget *label_email_address;
  GtkWidget *label_email;

  GtkWidget *label_tel_list;
  GtkWidget *label_tel_num;
  GtkWidget *label_tel_type;

  GtkWidget *label_company;
  GtkWidget *label_company_name;
  GtkWidget *label_operator;
  GtkWidget *label_fax;
  GtkWidget *label_green;
  GtkWidget *label_customer_care;

  GtkWidget *label_department;
  GtkWidget *label_work;
  GtkWidget *label_secretary;
  GtkWidget *label_secretary_phone;
  GtkWidget *label_sub_department;
  GtkWidget *label_organization;
  GtkWidget *label_assigment;

  GtkWidget *label_spouse_name;
  GtkWidget *label_married;
  GtkWidget *label_anniversary;
  GtkWidget *label_children;
  GtkWidget *label_child_notes;
  GtkWidget *label_hobby;
  GtkWidget *label_notes;
  GtkWidget *label_public_key;

  GtkWidget *label_modify;
  GtkWidget *label_delete;
  GtkWidget *label_create;
  GtkWidget *label_last_change;
  GtkWidget *label_birthday;
  GtkWidget *label_name;
  GtkWidget *label_other_notes;

  GtkWidget *label_io;
  GtkWidget *label_dict_name;

  GtkWidget *vseparator2;


  translation_frame = gtk_frame_new (_(" Rubrica Translation "));
  gtk_widget_show (translation_frame);
  gtk_container_set_border_width (GTK_CONTAINER (translation_frame), 2);

  box_translation = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (box_translation);
  gtk_container_add (GTK_CONTAINER (translation_frame), box_translation);
  gtk_container_set_border_width (GTK_CONTAINER (box_translation), 2);

  rules_frame = gtk_frame_new (_(" Rubrica's Dictionary "));
  gtk_widget_show (rules_frame);
  gtk_box_pack_start (GTK_BOX (box_translation), rules_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (rules_frame), 2);

  box_rules = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (box_rules);
  gtk_container_add (GTK_CONTAINER (rules_frame), box_rules);
  gtk_container_set_border_width (GTK_CONTAINER (box_rules), 2);

  box_dict = gtk_hbox_new (TRUE, 0);
  gtk_widget_show (box_dict);
  gtk_box_pack_start (GTK_BOX (box_rules), box_dict, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (box_dict), 2);

  label_dictionary = gtk_label_new (_("Rubrica will use:  "));
  gtk_widget_show (label_dictionary);
  gtk_box_pack_start (GTK_BOX (box_dict), label_dictionary, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dictionary), 0, 0.5);

  /*     RADIO BUTTONS
	 
         - DEFAULT DICTIONARY
	
	 - EXTERNAL DICTIONARY
	 
	 default: use one of the default dictionary
  */

  radio_external_dict = gtk_radio_button_new_with_label 
    (opt_other_lang_group,  _("an external dictionary     "));
  opt_other_lang_group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_external_dict));
  gtk_widget_set_name (radio_external_dict, "radio_external_dict");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_EXTERNAL, 
		       radio_external_dict);
  gtk_widget_show (radio_external_dict);
  gtk_box_pack_start (GTK_BOX (box_dict), radio_external_dict, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_external_dict, 
			_("uses an external dictionary when show preview"), NULL);

  radio_default_dict = gtk_radio_button_new_with_label(opt_other_lang_group, 
						       _("a default dictionary"));
  opt_other_lang_group = gtk_radio_button_group(GTK_RADIO_BUTTON (radio_default_dict));
  gtk_widget_set_name (radio_default_dict, "radio_default_dict");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_DEFAULT,
		       radio_default_dict);
  gtk_widget_show (radio_default_dict);
  gtk_box_pack_start (GTK_BOX (box_dict), radio_default_dict, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_default_dict, 
			_("uses one of the following default dictionary"), NULL);

  box_default_dict = gtk_hbox_new (TRUE, 0);
  gtk_widget_show (box_default_dict);
  gtk_box_pack_start (GTK_BOX (box_rules), box_default_dict, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (box_default_dict), 2);

  label_default_dict = gtk_label_new (_("Use as my default dictionary: "));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_default_dict", 
		       label_default_dict);  
  gtk_widget_show (label_default_dict);
  gtk_box_pack_start (GTK_BOX (box_default_dict), label_default_dict, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_default_dict), 0, 0.5);

  /*    RADIO BUTTONS
    
        - ITALIAN DICTIONARY
	
	- ENGLISH DICTIONARY

	default: use italian dictionary
  */
  radio_italian = gtk_radio_button_new_with_label (opt_def_lang_group, _("Italian"));
  opt_def_lang_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_italian));
  gtk_widget_set_name (radio_italian, "radio_italian");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_ITALIAN, 
		       radio_italian);
  gtk_widget_show (radio_italian);
  gtk_box_pack_start (GTK_BOX (box_default_dict), radio_italian, FALSE, TRUE, 0);

  radio_english = gtk_radio_button_new_with_label (opt_def_lang_group, _("English"));
  opt_def_lang_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_english));
  gtk_widget_set_name (radio_english, "radio_english");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_ENGLISH, 
		       radio_english);
  gtk_widget_show (radio_english);
  gtk_box_pack_start (GTK_BOX (box_default_dict), radio_english, FALSE, TRUE, 0);

  box_user_language = gtk_hbox_new (TRUE, 0);
  gtk_widget_show (box_user_language);
  gtk_box_pack_start (GTK_BOX (box_rules), box_user_language, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (box_user_language), 2);

  label_user_language = gtk_label_new (_("Rubrica will use this language:"));
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), "label_language",
		      label_user_language);
  gtk_widget_show (label_user_language);
  gtk_box_pack_start(GTK_BOX (box_user_language), label_user_language, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_user_language), 0, 0.5);
  
  /*    ENTRY TEXT

        USER LANGUAGES
   */
  entry_user_language = gtk_entry_new ();
  gtk_widget_set_name (entry_user_language, "entry_user_language");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_USER_DICTIONARY, 
		       entry_user_language);
  gtk_widget_show (entry_user_language);
  gtk_box_pack_start(GTK_BOX (box_user_language), entry_user_language, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, entry_user_language, 
			_("the language's name will be used as dictionary file name"),
			NULL);

  dictionary_frame = gtk_frame_new (_(" Dictionary "));
  gtk_widget_show (dictionary_frame);
  gtk_box_pack_start (GTK_BOX (box_translation), dictionary_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (dictionary_frame), 2);

  /*      dictionary notebook 
  */
  notebook_dict = gtk_notebook_new ();
  gtk_widget_set_name (notebook_dict, "notebook_dict");
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), "notebook_dict",notebook_dict);
  gtk_widget_show (notebook_dict);
  gtk_container_add (GTK_CONTAINER (dictionary_frame), notebook_dict);
  gtk_container_set_border_width (GTK_CONTAINER (notebook_dict), 2);

  frame_personal_data = gtk_frame_new (_(" Personal dictionary "));
  gtk_widget_show (frame_personal_data);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_personal_data);
  gtk_container_set_border_width (GTK_CONTAINER (frame_personal_data), 2);

  table_personal_data = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_personal_data);
  gtk_container_add (GTK_CONTAINER (frame_personal_data), table_personal_data);
  gtk_container_set_border_width (GTK_CONTAINER (table_personal_data), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_personal_data), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_personal_data), 10);


  /*    dictionary --  personal data
   */
  label_first_name = gtk_label_new (_("First Name"));
  gtk_widget_show (label_first_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_first_name, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_first_name), 0, 0.5);

  label_middle_name = gtk_label_new (_("Middle Name"));
  gtk_widget_show (label_middle_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_middle_name, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_middle_name), 0, 0.5);

  label_last_name = gtk_label_new (_("Last Name"));
  gtk_widget_show (label_last_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_last_name, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_last_name), 0, 0.5);

  label_profession = gtk_label_new (_("Profession"));
  gtk_widget_show (label_profession);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_profession, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_profession), 0, 0.5);

  label_name_prefix = gtk_label_new (_("Name Prefix"));
  gtk_table_attach (GTK_TABLE (table_personal_data), label_name_prefix, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_name_prefix), 0, 0.5);
  gtk_widget_show (label_name_prefix);

  label_title = gtk_label_new (_("Title"));
  gtk_widget_show (label_title);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_title, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_title), 0, 0.5);

  label_card = gtk_label_new (_("Card"));
  gtk_widget_show (label_card);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_card, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_card), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_card), 0, 0.5);

  label_data = gtk_label_new (_("Data"));
  gtk_widget_show (label_data);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_data, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_data), 0, 0.5);

  /*    personal dictionary entry
  */
  entry_first_name = gtk_entry_new ();
  gtk_widget_set_name (entry_first_name, "entry_first_name");
  gtk_widget_ref (entry_first_name);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_first_name", 
			    entry_first_name, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_first_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_first_name, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_middle_name = gtk_entry_new ();
  gtk_widget_set_name (entry_middle_name, "entry_middle_name");
  gtk_widget_ref (entry_middle_name);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_middle_name", 
			    entry_middle_name, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_middle_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_middle_name, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_last_name = gtk_entry_new ();
  gtk_widget_set_name (entry_last_name, "entry_last_name");
  gtk_widget_ref (entry_last_name);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_last_name", 
			    entry_last_name, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_last_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_last_name, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_profession = gtk_entry_new ();
  gtk_widget_set_name (entry_profession, "entry_profession");
  gtk_widget_ref (entry_profession);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_profession", 
			    entry_profession, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_profession);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_profession, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_name_prefix = gtk_entry_new ();
  gtk_widget_set_name (entry_name_prefix, "entry_name_prefix");
  gtk_widget_ref (entry_name_prefix);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_name_prefix", 
			    entry_name_prefix, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_name_prefix);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_name_prefix, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_title = gtk_entry_new ();
  gtk_widget_set_name (entry_title, "entry_title");
  gtk_widget_ref (entry_title);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_title", 
			    entry_title, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_title);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_title, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_card = gtk_entry_new ();
  gtk_widget_set_name (entry_card, "entry_card");
  gtk_widget_ref (entry_card);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_card", entry_card,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_card);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_card, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_data = gtk_entry_new ();
  gtk_widget_set_name (entry_data, "entry_data");
  gtk_widget_ref (entry_data);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_data", entry_data,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_data);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_data, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  
  personal_tab = gtk_label_new (_(" Personal "));
  gtk_widget_show (personal_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict),
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict),
							 0), personal_tab);
  /*    frame address
  */
  frame_address = gtk_frame_new (_(" Address  dictionary "));
  gtk_widget_show (frame_address);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_address);
  gtk_container_set_border_width (GTK_CONTAINER (frame_address), 2);

  table_address = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_address);
  gtk_container_add (GTK_CONTAINER (frame_address), table_address);
  gtk_container_set_border_width (GTK_CONTAINER (table_address), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_address), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_address), 3);

  label_street = gtk_label_new (_("Street"));
  gtk_widget_show (label_street);
  gtk_table_attach (GTK_TABLE (table_address), label_street, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_street), 0, 0.5);

  label_street_num = gtk_label_new (_("Street Number"));
  gtk_widget_show (label_street_num);
  gtk_table_attach (GTK_TABLE (table_address), label_street_num, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_street_num), 0, 0.5);

  label_zip_code = gtk_label_new (_("Zip Code"));
  gtk_widget_show (label_zip_code);
  gtk_table_attach (GTK_TABLE (table_address), label_zip_code, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_zip_code), 0, 0.5);

  label_city = gtk_label_new (_("City"));
  gtk_widget_show (label_city);
  gtk_table_attach (GTK_TABLE (table_address), label_city, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_city), 0, 0.5);

  label_province = gtk_label_new (_("Province"));
  gtk_widget_show (label_province);
  gtk_table_attach (GTK_TABLE (table_address), label_province, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_province), 0, 0.5);

  label_country = gtk_label_new (_("Country"));
  gtk_widget_show (label_country);
  gtk_table_attach (GTK_TABLE (table_address), label_country, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_country), 0, 0.5);

  label_state = gtk_label_new (_("State"));
  gtk_widget_show (label_state);
  gtk_table_attach (GTK_TABLE (table_address), label_state, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_state), 0, 0.5);

  label_address = gtk_label_new (_("Address"));
  gtk_widget_show (label_address);
  gtk_table_attach (GTK_TABLE (table_address), label_address, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_address), 0, 0.5);

  /*    address dictionary entry
  */
  entry_street = gtk_entry_new ();
  gtk_widget_set_name (entry_street, "entry_street");
  gtk_widget_ref (entry_street);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_street",
			    entry_street,  (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_street);
  gtk_table_attach (GTK_TABLE (table_address), entry_street, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_street_number = gtk_entry_new ();
  gtk_widget_set_name (entry_street_number, "entry_street_number");
  gtk_widget_ref (entry_street_number);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_street_number", 
			    entry_street_number, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_street_number);
  gtk_table_attach (GTK_TABLE (table_address), entry_street_number, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_city = gtk_entry_new ();
  gtk_widget_set_name (entry_city, "entry_city");
  gtk_widget_ref (entry_city);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_city",
			    entry_city, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_city);
  gtk_table_attach (GTK_TABLE (table_address), entry_city, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_state = gtk_entry_new ();
  gtk_widget_set_name (entry_state, "entry_state");
  gtk_widget_ref (entry_state);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_state", 
			    entry_state, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_state);
  gtk_table_attach (GTK_TABLE (table_address), entry_state, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_address = gtk_entry_new ();
  gtk_widget_set_name (entry_address, "entry_address");
  gtk_widget_ref (entry_address);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_address", 
			    entry_address, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_address);
  gtk_table_attach (GTK_TABLE (table_address), entry_address, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_zip_code = gtk_entry_new ();
  gtk_widget_set_name (entry_zip_code, "entry_zip_code");
  gtk_widget_ref (entry_zip_code);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_zip_code", 
			    entry_zip_code, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_zip_code);
  gtk_table_attach (GTK_TABLE (table_address), entry_zip_code, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_province = gtk_entry_new ();
  gtk_widget_set_name (entry_province, "entry_province");
  gtk_widget_ref (entry_province);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_province", 
			    entry_province, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_province);
  gtk_table_attach (GTK_TABLE (table_address), entry_province, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_country = gtk_entry_new ();
  gtk_widget_set_name (entry_country, "entry_country");
  gtk_widget_ref (entry_country);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_country", 
			    entry_country, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_country);
  gtk_table_attach (GTK_TABLE (table_address), entry_country, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  address_tab = gtk_label_new (_(" Address "));
  gtk_widget_show (address_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_dict), 
							1), address_tab);

  /*  frame net
   */
  frame_net = gtk_frame_new (_(" Net dictionary "));
  gtk_widget_show (frame_net);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_net);
  gtk_container_set_border_width (GTK_CONTAINER (frame_net), 2);

  table_net = gtk_table_new (3, 4, FALSE);
  gtk_widget_show (table_net);
  gtk_container_add (GTK_CONTAINER (frame_net), table_net);
  gtk_container_set_border_width (GTK_CONTAINER (table_net), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_net), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_net), 3);

  label_web = gtk_label_new (_("Web"));
  gtk_widget_show (label_web);
  gtk_table_attach (GTK_TABLE (table_net), label_web, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_web), 0, 0.5);

  label_email_address = gtk_label_new (_("Email Address"));
  gtk_widget_show (label_email_address);
  gtk_table_attach (GTK_TABLE (table_net), label_email_address, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_email_address), 0, 0.5);

  label_email = gtk_label_new (_("Email"));
  gtk_widget_show (label_email);
  gtk_table_attach (GTK_TABLE (table_net), label_email, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_email), 0, 0.5);

  label_web_address = gtk_label_new (_("Web Address"));
  gtk_widget_show (label_web_address);
  gtk_table_attach (GTK_TABLE (table_net), label_web_address, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_web_address), 0, 0.5);

  /*    net dictionary entry
  */
  entry_web_address = gtk_entry_new ();
  gtk_widget_set_name (entry_web_address, "entry_web_address");
  gtk_widget_ref (entry_web_address);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_web_address",
			    entry_web_address, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_web_address);
  gtk_table_attach (GTK_TABLE (table_net), entry_web_address, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_web = gtk_entry_new ();
  gtk_widget_set_name (entry_web, "entry_web");
  gtk_widget_ref (entry_web);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_web", entry_web,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_web);
  gtk_table_attach (GTK_TABLE (table_net), entry_web, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_email = gtk_entry_new ();
  gtk_widget_set_name (entry_email, "entry_email");
  gtk_widget_ref (entry_email);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_email",
			    entry_email, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_email);
  gtk_table_attach (GTK_TABLE (table_net), entry_email, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_email_address = gtk_entry_new ();
  gtk_widget_set_name (entry_email_address, "entry_email_address");
  gtk_widget_ref (entry_email_address);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_email_address", 
			    entry_email_address, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_email_address);
  gtk_table_attach (GTK_TABLE (table_net), entry_email_address, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  net_tab = gtk_label_new (_(" Net "));
  gtk_widget_set_name (net_tab, "net_tab");
  gtk_widget_ref (net_tab);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "net_tab", net_tab,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (net_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK 
							 (notebook_dict), 2), net_tab);

  /*    frame telephone
  */
  frame_telephone = gtk_frame_new (_(" Telephone dictionary "));
  gtk_widget_show (frame_telephone);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_telephone);
  gtk_container_set_border_width (GTK_CONTAINER (frame_telephone), 2);

  table_telephone = gtk_table_new (3, 4, FALSE);
  gtk_widget_show (table_telephone);
  gtk_container_add (GTK_CONTAINER (frame_telephone), table_telephone);
  gtk_container_set_border_width (GTK_CONTAINER (table_telephone), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_telephone), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_telephone), 3);

  label_tel_list = gtk_label_new (_("Telephone List"));
  gtk_widget_show (label_tel_list);
  gtk_table_attach (GTK_TABLE (table_telephone), label_tel_list, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_tel_list), 0, 0.5);

  label_tel_num = gtk_label_new (_("Telephone "));
  gtk_widget_show (label_tel_num);
  gtk_table_attach (GTK_TABLE (table_telephone), label_tel_num, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_tel_num), 0, 0.5);

  label_tel_type = gtk_label_new (_("Type"));
  gtk_widget_show (label_tel_type);
  gtk_table_attach (GTK_TABLE (table_telephone), label_tel_type, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_tel_type), 0, 0.5);

  /*    telephone dictionary entry
  */
  entry_tel_list = gtk_entry_new ();
  gtk_widget_set_name (entry_tel_list, "entry_tel_list");
  gtk_widget_ref (entry_tel_list);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_tel_list", 
			    entry_tel_list, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_tel_list);
  gtk_table_attach (GTK_TABLE (table_telephone), entry_tel_list, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_telephone = gtk_entry_new ();
  gtk_widget_set_name (entry_telephone, "entry_telephone");
  gtk_widget_ref (entry_telephone);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_telephone", 
			    entry_telephone, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_telephone);
  gtk_table_attach (GTK_TABLE (table_telephone), entry_telephone, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_type = gtk_entry_new ();
  gtk_widget_set_name (entry_type, "entry_type");
  gtk_widget_ref (entry_type);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_type",
			    entry_type, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_type);
  gtk_table_attach (GTK_TABLE (table_telephone), entry_type, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  telephone_tab = gtk_label_new (_("Telephone"));
  gtk_widget_show (telephone_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict),
							 3), telephone_tab);

  /*    company frame
  */
  frame_company = gtk_frame_new (_(" Company dictionary "));
  gtk_widget_show (frame_company);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_company);
  gtk_container_set_border_width (GTK_CONTAINER (frame_company), 2);

  table_compamy = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_compamy);
  gtk_container_add (GTK_CONTAINER (frame_company), table_compamy);
  gtk_container_set_border_width (GTK_CONTAINER (table_compamy), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_compamy), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_compamy), 3);

  label_company_name = gtk_label_new (_("Company Name"));
  gtk_widget_show (label_company_name);
  gtk_table_attach (GTK_TABLE (table_compamy), label_company_name, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_company_name), 0, 0.5);

  label_operator = gtk_label_new (_("Operator"));
  gtk_widget_show (label_operator);
  gtk_table_attach (GTK_TABLE (table_compamy), label_operator, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_operator), 0, 0.5);

  label_fax = gtk_label_new (_("Fax"));
  gtk_widget_show (label_fax);
  gtk_table_attach (GTK_TABLE (table_compamy), label_fax, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_fax), 0, 0.5);

  label_green = gtk_label_new (_("Green"));
  gtk_widget_show (label_green);
  gtk_table_attach (GTK_TABLE (table_compamy), label_green, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_green), 0, 0.5);

  label_customer_care = gtk_label_new (_("Customer Care"));
  gtk_widget_show (label_customer_care);
  gtk_table_attach (GTK_TABLE (table_compamy), label_customer_care, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_customer_care), 0, 0.5);

  label_company = gtk_label_new (_("Company"));
  gtk_widget_show (label_company);
  gtk_table_attach (GTK_TABLE (table_compamy), label_company, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_company), 0, 0.5);

  /*    company dictionary entry
  */
  entry_company_name = gtk_entry_new ();
  gtk_widget_set_name (entry_company_name, "entry_company_name");
  gtk_widget_ref (entry_company_name);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_company_name", 
			    entry_company_name, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_company_name);
  gtk_table_attach (GTK_TABLE (table_compamy), entry_company_name, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_operator = gtk_entry_new ();
  gtk_widget_set_name (entry_operator, "entry_operator");
  gtk_widget_ref (entry_operator);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_operator", 
			    entry_operator, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_operator);
  gtk_table_attach (GTK_TABLE (table_compamy), entry_operator, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_green = gtk_entry_new ();
  gtk_widget_set_name (entry_green, "entry_green");
  gtk_widget_ref (entry_green);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_green", 
			    entry_green, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_green);
  gtk_table_attach (GTK_TABLE (table_compamy), entry_green, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_company = gtk_entry_new ();
  gtk_widget_set_name (entry_company, "entry_company");
  gtk_widget_ref (entry_company);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_company", 
			    entry_company, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_company);
  gtk_table_attach (GTK_TABLE (table_compamy), entry_company, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_customer_care = gtk_entry_new ();
  gtk_widget_set_name (entry_customer_care, "entry_customer_care");
  gtk_widget_ref (entry_customer_care);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_customer_care",
			    entry_customer_care, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_customer_care);
  gtk_table_attach (GTK_TABLE (table_compamy), entry_customer_care, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_fax = gtk_entry_new ();
  gtk_widget_set_name (entry_fax, "entry_fax");
  gtk_widget_ref (entry_fax);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_fax", 
			    entry_fax, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_fax);
  gtk_table_attach (GTK_TABLE (table_compamy), entry_fax, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  company_tab = gtk_label_new (_(" Company "));
  gtk_widget_show (company_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict), 
							 4), company_tab);

  /*    work frame
   */
  frame_work = gtk_frame_new (_(" Work dictionary "));
  gtk_widget_show (frame_work);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_work);
  gtk_container_set_border_width (GTK_CONTAINER (frame_work), 2);

  table_work = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_work);
  gtk_container_add (GTK_CONTAINER (frame_work), table_work);
  gtk_container_set_border_width (GTK_CONTAINER (table_work), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_work), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_work), 3);

  label_department = gtk_label_new (_("Department"));
  gtk_widget_show (label_department);
  gtk_table_attach (GTK_TABLE (table_work), label_department, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_department), 0, 0.5);

  label_secretary = gtk_label_new (_("Secretary"));
  gtk_widget_show (label_secretary);
  gtk_table_attach (GTK_TABLE (table_work), label_secretary, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_secretary), 0, 0.5);

  label_work = gtk_label_new (_("Work"));
  gtk_widget_show (label_work);
  gtk_table_attach (GTK_TABLE (table_work), label_work, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_work), 0, 0.5);

  label_secretary_phone = gtk_label_new (_("Secretary Phone"));
  gtk_widget_show (label_secretary_phone);
  gtk_table_attach (GTK_TABLE (table_work), label_secretary_phone, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_secretary_phone), 0, 0.5);

  label_sub_department = gtk_label_new (_("Sub Department"));
  gtk_widget_show (label_sub_department);
  gtk_table_attach (GTK_TABLE (table_work), label_sub_department, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_sub_department), 0, 0.5);

  label_organization = gtk_label_new (_("Organization"));
  gtk_widget_show (label_organization);
  gtk_table_attach (GTK_TABLE (table_work), label_organization, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_organization), 0, 0.5);

  label_assigment = gtk_label_new (_("Assigment"));
  gtk_widget_show (label_assigment);
  gtk_table_attach (GTK_TABLE (table_work), label_assigment, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_assigment), 0, 0.5);

  /*    work dictionary entry
  */
  entry_assigment = gtk_entry_new ();
  gtk_widget_set_name (entry_assigment, "entry_assigment");
  gtk_widget_ref (entry_assigment);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_assigment", 
			    entry_assigment, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_assigment);
  gtk_table_attach (GTK_TABLE (table_work), entry_assigment, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_organization = gtk_entry_new ();
  gtk_widget_set_name (entry_organization, "entry_organization");
  gtk_widget_ref (entry_organization);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_organization", 
			    entry_organization, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_organization);
  gtk_table_attach (GTK_TABLE (table_work), entry_organization, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_sub_dep = gtk_entry_new ();
  gtk_widget_set_name (entry_sub_dep, "entry_sub_dep");
  gtk_widget_ref (entry_sub_dep);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_sub_dep", 
			    entry_sub_dep, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_sub_dep);
  gtk_table_attach (GTK_TABLE (table_work), entry_sub_dep, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_secretary_phone = gtk_entry_new ();
  gtk_widget_set_name (entry_secretary_phone, "entry_secretary_phone");
  gtk_widget_ref (entry_secretary_phone);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_secretary_phone",
			    entry_secretary_phone,(GtkDestroyNotify)gtk_widget_unref);
  gtk_widget_show (entry_secretary_phone);
  gtk_table_attach (GTK_TABLE (table_work), entry_secretary_phone, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_department = gtk_entry_new ();
  gtk_widget_set_name (entry_department, "entry_department");
  gtk_widget_ref (entry_department);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_department", 
			    entry_department, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_department);
  gtk_table_attach (GTK_TABLE (table_work), entry_department, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_secretary = gtk_entry_new ();
  gtk_widget_set_name (entry_secretary, "entry_secretary");
  gtk_widget_ref (entry_secretary);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_secretary", 
			    entry_secretary, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_secretary);
  gtk_table_attach (GTK_TABLE (table_work), entry_secretary, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_work = gtk_entry_new ();
  gtk_widget_set_name (entry_work, "entry_work");
  gtk_widget_ref (entry_work);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_work",
			    entry_work, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_work);
  gtk_table_attach (GTK_TABLE (table_work), entry_work, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  work_tab = gtk_label_new (_(" Work "));
  gtk_widget_show (work_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict),
							 5), work_tab);

  /*    frame notes
  */
  frame_notes = gtk_frame_new (_(" Notes dictionary "));
  gtk_widget_show (frame_notes);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_notes);
  gtk_container_set_border_width (GTK_CONTAINER (frame_notes), 2);

  table_notes = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_notes);
  gtk_container_add (GTK_CONTAINER (frame_notes), table_notes);
  gtk_container_set_border_width (GTK_CONTAINER (table_notes), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_notes), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_notes), 3);

  label_spouse_name = gtk_label_new (_("Spouse Name"));
  gtk_widget_show (label_spouse_name);
  gtk_table_attach (GTK_TABLE (table_notes), label_spouse_name, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_spouse_name), 0, 0.5);

  label_married = gtk_label_new (_("Married"));
  gtk_widget_show (label_married);
  gtk_table_attach (GTK_TABLE (table_notes), label_married, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_married), 0, 0.5);

  label_anniversary = gtk_label_new (_("Anniversary"));
  gtk_widget_show (label_anniversary);
  gtk_table_attach (GTK_TABLE (table_notes), label_anniversary, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_anniversary), 0, 0.5);

  label_children = gtk_label_new (_("Children"));
  gtk_widget_show (label_children);
  gtk_table_attach (GTK_TABLE (table_notes), label_children, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_children), 0, 0.5);

  label_child_notes = gtk_label_new (_("Children Notes"));
  gtk_widget_show (label_child_notes);
  gtk_table_attach (GTK_TABLE (table_notes), label_child_notes, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_child_notes), 0, 0.5);

  label_hobby = gtk_label_new (_("Hobby"));
  gtk_widget_show (label_hobby);
  gtk_table_attach (GTK_TABLE (table_notes), label_hobby, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_hobby), 0, 0.5);

  label_notes = gtk_label_new (_("Note"));
  gtk_widget_show (label_notes);
  gtk_table_attach (GTK_TABLE (table_notes), label_notes, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_notes), 0, 0.5);

  label_public_key = gtk_label_new (_("Public Key"));
  gtk_widget_show (label_public_key);
  gtk_table_attach (GTK_TABLE (table_notes), label_public_key, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_public_key), 0, 0.5);

  entry_anniversary = gtk_entry_new ();
  gtk_widget_set_name (entry_anniversary, "entry_anniversary");
  gtk_widget_ref (entry_anniversary);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_anniversary", 
			    entry_anniversary, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_anniversary);
  gtk_table_attach (GTK_TABLE (table_notes), entry_anniversary, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_spouse_name = gtk_entry_new ();
  gtk_widget_set_name (entry_spouse_name, "entry_spouse_name");
  gtk_widget_ref (entry_spouse_name);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_spouse_name", 
			    entry_spouse_name, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_spouse_name);
  gtk_table_attach (GTK_TABLE (table_notes), entry_spouse_name, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_married = gtk_entry_new ();
  gtk_widget_set_name (entry_married, "entry_married");
  gtk_widget_ref (entry_married);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_married", 
			    entry_married, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_married);
  gtk_table_attach (GTK_TABLE (table_notes), entry_married, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_children = gtk_entry_new ();
  gtk_widget_set_name (entry_children, "entry_children");
  gtk_widget_ref (entry_children);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_children", 
			    entry_children, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_children);
  gtk_table_attach (GTK_TABLE (table_notes), entry_children, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_hobby = gtk_entry_new ();
  gtk_widget_set_name (entry_hobby, "entry_hobby");
  gtk_widget_ref (entry_hobby);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_hobby", 
			    entry_hobby, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_hobby);
  gtk_table_attach (GTK_TABLE (table_notes), entry_hobby, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_public_key = gtk_entry_new ();
  gtk_widget_set_name (entry_public_key, "entry_public_key");
  gtk_widget_ref (entry_public_key);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_public_key",
			    entry_public_key, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_public_key);
  gtk_table_attach (GTK_TABLE (table_notes), entry_public_key, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_notes = gtk_entry_new ();
  gtk_widget_set_name (entry_notes, "entry_notes");
  gtk_widget_ref (entry_notes);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_notes", 
			    entry_notes, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_notes);
  gtk_table_attach (GTK_TABLE (table_notes), entry_notes, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_child_notes = gtk_entry_new ();
  gtk_widget_set_name (entry_child_notes, "entry_child_notes");
  gtk_widget_ref (entry_child_notes);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_child_notes", 
			    entry_child_notes, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_child_notes);
  gtk_table_attach (GTK_TABLE (table_notes), entry_child_notes, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  notes_tab = gtk_label_new (_(" Notes "));
  gtk_widget_show (notes_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict),
							 6), notes_tab);
  /*    frame misc
  */
  frame_misc = gtk_frame_new (_(" Misc dictionary"));
  gtk_widget_show (frame_misc);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_misc);
  gtk_container_set_border_width (GTK_CONTAINER (frame_misc), 2);

  table_misc = gtk_table_new (5, 4, FALSE);
  gtk_widget_show (table_misc);
  gtk_container_add (GTK_CONTAINER (frame_misc), table_misc);
  gtk_container_set_border_width (GTK_CONTAINER (table_misc), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_misc), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_misc), 3);

  label_delete = gtk_label_new (_("Deleting"));
  gtk_widget_show (label_delete);
  gtk_table_attach (GTK_TABLE (table_misc), label_delete, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_delete), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_delete), 0, 0.5);

  label_modify = gtk_label_new (_("Modifying"));
  gtk_widget_show (label_modify);
  gtk_table_attach (GTK_TABLE (table_misc), label_modify, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_modify), 0, 0.5);

  label_create = gtk_label_new (_("Created"));
  gtk_widget_show (label_create);
  gtk_table_attach (GTK_TABLE (table_misc), label_create, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_create), 0, 0.5);

  label_last_change = gtk_label_new (_("Last Change"));
  gtk_widget_show (label_last_change);
  gtk_table_attach (GTK_TABLE (table_misc), label_last_change, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_last_change), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_last_change), 0, 0.5);

  label_birthday = gtk_label_new (_("Birthday"));
  gtk_widget_show (label_birthday);
  gtk_table_attach (GTK_TABLE (table_misc), label_birthday, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_birthday), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_birthday), 0, 0.5);

  /* label card name */
  label_name = gtk_label_new (_("Name"));
  gtk_widget_show (label_name);
  gtk_table_attach (GTK_TABLE (table_misc), label_name, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_name), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_name), 0, 0.5);

  label_other_notes = gtk_label_new (_("Other Notes"));
  gtk_widget_show (label_other_notes);
  gtk_table_attach (GTK_TABLE (table_misc), label_other_notes, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_other_notes), 0, 0.5);

  entry_delete = gtk_entry_new ();
  gtk_widget_set_name (entry_delete, "entry_delete");
  gtk_widget_ref (entry_delete);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_delete", 
			    entry_delete, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_delete);
  gtk_table_attach (GTK_TABLE (table_misc), entry_delete, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_modify = gtk_entry_new ();
  gtk_widget_set_name (entry_modify, "entry_modify");
  gtk_widget_ref (entry_modify);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_modify", 
			    entry_modify, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_modify);
  gtk_table_attach (GTK_TABLE (table_misc), entry_modify, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_last_change = gtk_entry_new ();
  gtk_widget_set_name (entry_last_change, "entry_last_change");
  gtk_widget_ref (entry_last_change);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_last_change", 
			    entry_last_change, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_last_change);
  gtk_table_attach (GTK_TABLE (table_misc), entry_last_change, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_name = gtk_entry_new ();
  gtk_widget_set_name (entry_name, "entry_name");
  gtk_widget_ref (entry_name);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_name", entry_name,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_name);
  gtk_table_attach (GTK_TABLE (table_misc), entry_name, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_created = gtk_entry_new ();
  gtk_widget_set_name (entry_created, "entry_created");
  gtk_widget_ref (entry_created);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_created", 
			    entry_created, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_created);
  gtk_table_attach (GTK_TABLE (table_misc), entry_created, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_birthday = gtk_entry_new ();
  gtk_widget_set_name (entry_birthday, "entry_birthday");
  gtk_widget_ref (entry_birthday);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_birthday", 
			    entry_birthday, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_birthday);
  gtk_table_attach (GTK_TABLE (table_misc), entry_birthday, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_other_notes = gtk_entry_new ();
  gtk_widget_set_name (entry_other_notes, "entry_other_notes");
  gtk_widget_ref (entry_other_notes);
  gtk_object_set_data_full (GTK_OBJECT (preferences_dialog), "entry_other_notes", 
			    entry_other_notes, (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_other_notes);
  gtk_table_attach (GTK_TABLE (table_misc), entry_other_notes, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  misc_tab = gtk_label_new (_("Misc "));
  gtk_widget_show (misc_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_dict),
							 7), misc_tab);

  /*    IO frame
  */
  io_frame = gtk_frame_new (_(" Save and Load Dictionary"));
  gtk_widget_show (io_frame);
  gtk_box_pack_start (GTK_BOX (box_translation), io_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (io_frame), 2);

  box_io = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (box_io);
  gtk_container_add (GTK_CONTAINER (io_frame), box_io);
  gtk_container_set_border_width (GTK_CONTAINER (box_io), 2);


  /*      input/output labels 
   */
  label_io = gtk_label_new (_("Dictionary name:"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_io", label_io);
  gtk_widget_show (label_io);
  gtk_box_pack_start (GTK_BOX (box_io), label_io, FALSE, FALSE, 0);
 
  label_dict_name = gtk_label_new ("");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_dict_name", 
		       label_dict_name);
  gtk_widget_show (label_dict_name);
  gtk_box_pack_start (GTK_BOX (box_io), label_dict_name, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label_dict_name), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_dict_name), 0, 0.5);
  
  vseparator2 = gtk_vseparator_new ();
  gtk_widget_show (vseparator2);
  gtk_box_pack_start (GTK_BOX (box_io), vseparator2, FALSE, TRUE, 0);

  buttonbox_io = gtk_hbutton_box_new ();
  gtk_widget_show (buttonbox_io);
  gtk_box_pack_start (GTK_BOX (box_io), buttonbox_io, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (buttonbox_io), 2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (buttonbox_io), GTK_BUTTONBOX_SPREAD);
  gtk_button_box_set_spacing (GTK_BUTTON_BOX (buttonbox_io), 5);
  gtk_button_box_set_child_size (GTK_BUTTON_BOX (buttonbox_io), 80, 27);
  gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (buttonbox_io), 4, 0);

  /*    load and save dictionary buttons
  */
  load = gtk_button_new_with_label (_("Load"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "load", load);
  gtk_widget_show (load);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), load);
  GTK_WIDGET_SET_FLAGS (load, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, load, _("Load dictionary and show it"), NULL);

  save = gtk_button_new_with_label (_("Save"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "save", save);
  gtk_widget_show (save);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), save);
  GTK_WIDGET_SET_FLAGS (save, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, save, _("Save dictionary"), NULL);

  show_rules = gtk_button_new_with_label (_("Show Rules"));
  gtk_widget_show (show_rules);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), show_rules);
  GTK_WIDGET_SET_FLAGS (show_rules, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, show_rules, _("Show translation rules"), NULL);


  /* ---------------------------------------------------------------------
     GConf settings
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio_dictionary(radio_external_dict, 
						 radio_default_dict, client, 
						 RUBRICA_KEY_EXTERNAL,
						 RUBRICA_KEY_DEFAULT);  

  rubrica_preferences_configure_radio(radio_italian, radio_english, client, 
				      RUBRICA_KEY_ITALIAN, RUBRICA_KEY_ENGLISH);  

  rubrica_preferences_configure_label(label_dict_name, client, 
				      RUBRICA_KEY_USER_DICTIONARY);

  rubrica_preferences_configure_entry(entry_user_language, client, 
				      RUBRICA_KEY_USER_DICTIONARY);

  /* ---------------------------------------------------------------------  */

  gtk_signal_connect (GTK_OBJECT (radio_external_dict), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_witch_dict_toggled),
                      RUBRICA_KEY_EXTERNAL);
  gtk_signal_connect (GTK_OBJECT (radio_default_dict), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_witch_dict_toggled),
                      RUBRICA_KEY_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (radio_italian), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_dictionary_toggled),
                      RUBRICA_KEY_ITALIAN);
  gtk_signal_connect (GTK_OBJECT (radio_english), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_button_toggled),
//                      GTK_SIGNAL_FUNC (on_radio_dictionary_toggled),
                      RUBRICA_KEY_ENGLISH);

  gtk_signal_connect (GTK_OBJECT (entry_user_language), "changed",
		      GTK_SIGNAL_FUNC (on_entry_changed),
//                      GTK_SIGNAL_FUNC (on_entry_user_lang_changed),
                      RUBRICA_KEY_USER_DICTIONARY);

  /*    dictionary entry callbacks
  */
  
  /*    personal
  */
  gtk_signal_connect (GTK_OBJECT (entry_first_name), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_FIRST_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_middle_name), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_MIDDLE_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_last_name), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_LAST_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_profession), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_PROFESSION);
  gtk_signal_connect (GTK_OBJECT (entry_name_prefix), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_NAME_PREFIX);
  gtk_signal_connect (GTK_OBJECT (entry_title), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TITLE);
  gtk_signal_connect (GTK_OBJECT (entry_card), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CARD);
  gtk_signal_connect (GTK_OBJECT (entry_data), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_DATA);

  /*    address
  */
  gtk_signal_connect (GTK_OBJECT (entry_address), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ADDRESS);
  gtk_signal_connect (GTK_OBJECT (entry_street), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_STREET);
  gtk_signal_connect (GTK_OBJECT (entry_street_number), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
		      RUBRICA_KEY_DICT_STREET_NUMBER);
  gtk_signal_connect (GTK_OBJECT (entry_zip_code), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ZIP_CODE);
  gtk_signal_connect (GTK_OBJECT (entry_city), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CITY);
  gtk_signal_connect (GTK_OBJECT (entry_province), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_PROVINCE);
  gtk_signal_connect (GTK_OBJECT (entry_country), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
		      RUBRICA_KEY_DICT_COUNTRY);
  gtk_signal_connect (GTK_OBJECT (entry_state), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_STATE);

  /*    net
  */
  gtk_signal_connect (GTK_OBJECT (entry_web_address), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_WEB_ADDRESS);
  gtk_signal_connect (GTK_OBJECT (entry_web), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_WEB);
  gtk_signal_connect (GTK_OBJECT (entry_email_address), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_EMAIL_ADDRESS);
  gtk_signal_connect (GTK_OBJECT (entry_email), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_EMAIL);

  /*    telephone
  */
  gtk_signal_connect (GTK_OBJECT (entry_tel_list), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_LIST);
  gtk_signal_connect (GTK_OBJECT (entry_telephone), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_NUMBER);
  gtk_signal_connect (GTK_OBJECT (entry_type), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_TYPE);

  /*    company
  */
  gtk_signal_connect (GTK_OBJECT (entry_company_name), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_COMPANY_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_operator), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_OPERATOR);
  gtk_signal_connect (GTK_OBJECT (entry_green), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_GREEN);
  gtk_signal_connect (GTK_OBJECT (entry_company), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_COMPANY);
  gtk_signal_connect (GTK_OBJECT (entry_customer_care), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CUSTOMER_CARE);
   gtk_signal_connect (GTK_OBJECT (entry_fax), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_FAX);
 
  /*    work
   */
  gtk_signal_connect (GTK_OBJECT (entry_work), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_WORK);
  gtk_signal_connect (GTK_OBJECT (entry_assigment), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ASSIGMENT);
  gtk_signal_connect (GTK_OBJECT (entry_organization), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ORGANIZATION);
  gtk_signal_connect (GTK_OBJECT (entry_department), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_DEPARTMENT);
  gtk_signal_connect (GTK_OBJECT (entry_sub_dep), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SUB_DEPARTMENT);
  gtk_signal_connect (GTK_OBJECT (entry_secretary), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SECRETARY);
  gtk_signal_connect (GTK_OBJECT (entry_secretary_phone), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SECRETARY_PHONE);

  /*    notes
   */
  gtk_signal_connect (GTK_OBJECT (entry_spouse_name), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_SPOUSE_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_married), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_MARRIED);
  gtk_signal_connect (GTK_OBJECT (entry_anniversary), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_ANNIVERSARY);
  gtk_signal_connect (GTK_OBJECT (entry_children), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CHILDREN);
  gtk_signal_connect (GTK_OBJECT (entry_child_notes), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CHILDREN_NOTES);
  gtk_signal_connect (GTK_OBJECT (entry_hobby), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_HOBBY);
  gtk_signal_connect (GTK_OBJECT (entry_notes), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_NOTES);
  gtk_signal_connect (GTK_OBJECT (entry_public_key), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_PUBLIC_KEY);

  /*    misc
  */
  gtk_signal_connect (GTK_OBJECT (entry_modify), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_MODIFY);
  gtk_signal_connect (GTK_OBJECT (entry_delete), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_DELETE);
  gtk_signal_connect (GTK_OBJECT (entry_created), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CREATED);
  gtk_signal_connect (GTK_OBJECT (entry_last_change), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_LAST_CHANGE);
  gtk_signal_connect (GTK_OBJECT (entry_name), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_CARD_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_birthday), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_BIRTHDAY);
  gtk_signal_connect (GTK_OBJECT (entry_other_notes), "changed",
                      GTK_SIGNAL_FUNC (on_dictionary_entry_changed),
                      RUBRICA_KEY_DICT_OTHER_NOTES);

  /*      notebook dictionary buttons callbacks 
  */
  gtk_signal_connect (GTK_OBJECT (load), "clicked",
                      GTK_SIGNAL_FUNC (on_load_dictionary_clicked),
                      entry_user_language);
  gtk_signal_connect (GTK_OBJECT (save), "clicked",
                      GTK_SIGNAL_FUNC (on_save_dictionary_clicked),
		      entry_user_language);
  gtk_signal_connect (GTK_OBJECT (show_rules), "clicked",
                      GTK_SIGNAL_FUNC (on_show_rules_clicked),
                      NULL);

  return (GtkWidget *) translation_frame;
}







